@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu-tab.h,v 1.19 2009/01/04 00:24:51 bowkenken Exp $
+* $Id: amenu-tab.h,v 1.24 2011/01/09 01:58:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_TAB_H
@@ -34,8 +34,8 @@
 /* ưޡ˥塼 */
 
 static menu_t	ls_menu_auto_mark
-		[1 + 1 + (14 * AUTO_MARK_MAX_N)
-		+ (2 * AUTO_MARK_PAGE_N) + 2];
+		[1 + (14 * AUTO_MARK_MAX_N)
+		+ (3 * AUTO_MARK_PAGE_N) + 2];
 
 static menu_t	ls_menu_appoint_item
 		[1 + 1 + (AUTO_MARK_APPOINT_ITEM_MAX_N * 2) + 1];
@@ -61,6 +61,17 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		NULL,
 		FLG_NULL,
 	},
+/* Position */
+	{
+		"/edit/position",
+		"<Item>",
+		'F',
+		"",
+		N_MSG_NULL, "",
+		cb_menu_auto_mark_position,
+		NULL,
+		FLG_NULL,
+	},
 /* Target */
 	{
 		"/edit/target",
@@ -533,7 +544,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		"<Item>",
 		'W',
 		"",
-		N_MSG_MENU_AUTO_MARK_COPY, "",
+		N_MSG_MENU_AUTO_MARK_COPY_S, "",
 		cb_menu_auto_mark_copy_small,
 		NULL,
 		FLG_NULL,
@@ -543,7 +554,7 @@ static menu_t	ls_menu_auto_mark_edit[] = {
 		"<Item>",
 		'Y',
 		"",
-		N_MSG_MENU_AUTO_MARK_PASTE, "",
+		N_MSG_MENU_AUTO_MARK_PASTE_S, "",
 		cb_menu_auto_mark_paste_small,
 		NULL,
 		FLG_NULL,
