@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.h,v 1.18 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: amenu.h,v 1.24 2011/01/09 01:58:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_H
@@ -37,8 +37,8 @@
 
 /* ưޡκ */
 #define	AUTO_MARK_N_PER_PAGE	10
-#define	AUTO_MARK_PAGE_N	5
-#define	AUTO_MARK_MAX_N	(AUTO_MARK_N_PER_PAGE * AUTO_MARK_PAGE_N)
+#define	AUTO_MARK_PAGE_N	6
+#define	AUTO_MARK_MAX_N		(AUTO_MARK_N_PER_PAGE * AUTO_MARK_PAGE_N)
 
 /* ȥκʸ */
 #define	MSG_TTL_AUTO_MARK_MAX_LEN	64
@@ -54,6 +54,9 @@
 /* ƥμκ */
 #define	AUTO_MARK_APPOINT_ITEM_MAX_N	64
 
+/* С֤饻ѤμưޡåֹѴβ */
+#define	AUTO_MARK_POSITION_MUL	1000
+
 /***************************************************************
 * ե饰
 * ֤Ѥϥ֡ǡ⽤
@@ -144,6 +147,41 @@ typedef enum {
 	AUTO_MARK_COND_MP_MAX,
 } auto_mark_cond_t;
 
+/***************************************************************
+* ǥեȤμưޡμ
+***************************************************************/
+
+typedef enum {
+	DFLT_AUTO_MARK_NULL,
+
+	/* Ʈ(ɲ) */
+	DFLT_AUTO_MARK_FIGHT,
+	/* Ʈ() */
+	DFLT_AUTO_MARK_FIGHT_PRIO,
+
+	/* ܶƮ(ɲ) */
+	DFLT_AUTO_MARK_FIGHT_NO_THROW,
+	/* ܶƮ() */
+	DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO,
+
+	/* (ɲ) */
+	DFLT_AUTO_MARK_FIGHT_ALL,
+	/* () */
+	DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
+
+	/* ƤΥƥ */
+	DFLT_AUTO_MARK_ITEM_ALL,
+	/* äƤ륢ƥ */
+	DFLT_AUTO_MARK_ITEM_OWN,
+
+	/*  */
+	DFLT_AUTO_MARK_RETREAT,
+	/*  */
+	DFLT_AUTO_MARK_CLEAR,
+
+	DFLT_AUTO_MARK_MAX_N,
+} dflt_auto_mark_t;
+
 /***************************************************************
 * ưޡ
 ***************************************************************/
@@ -155,6 +193,8 @@ typedef struct {
 	auto_mark_cond_t	cond;
 	char	macro[MACRO_MAX_LEN + 1];
 	unsigned long	flg;
+
+	dflt_auto_mark_t	dflt;
 } auto_mark_t;
 
 #endif	/* AMENU_H */
