@@ -6,17 +6,32 @@ extern "C" {
 
 void	gui_begin( void );
 void	gui_end( void );
+void	call_alloc_autorelease_pool( void );
+void	call_release_autorelease_pool( void );
+void	call_close_game_gui( void );
 void	key_buf_lock( void );
 void	key_buf_unlock( void );
 bool_t	call_game_thread_create( void *(*func)( void * ) );
 bool_t	call_game_thread_exit(
 	void *(*func)( void * ), long code
 );
+const char	*call_get_home_dir( void );
 void	call_ena_timer( void );
 void	call_gui_map_cont_exec_set( bool_t flagExec );
 void	call_gui_map_print_stat_bar_hint( void );
 void	call_gui_menu_draw( draw_menu_t *data );
 void	call_gui_menu_wipe( void );
+long	call_cui_mouse_check_event( long c );
+void	call_cui_mouse_reset_handler_tab( void );
+long	call_cui_mouse_add_handler(
+	bool_t flagEnable,
+	long x, long y, long w, long h,
+	bool_t (*funcPoint)( long btn, long n, const char *macro ),
+	bool_t (*funcClick)( long btn, long n, const char *macro ),
+	bool_t (*funcScroll)( long btn, long n, const char *macro ),
+	long n,
+	const char *macro
+);
 void	call_set_mouse_dflt_menu( long sel_n );
 void	call_gui_message_set_flag_more( bool_t flag );
 void	call_gui_message_draw( void );
@@ -45,7 +60,6 @@ void	call_gui_skill_edit_wipe( void );
 void	call_gui_chr_sheet_draw( mbr_t *org, mbr_t *mbr );
 void	call_gui_chr_sheet_redraw( mbr_t *org, mbr_t *mbr );
 void	call_gui_chr_sheet_wipe();
-void	call_set_str_dir_sel_graph( char *dir );
 bool_t	call_sel_conf_eval_block_begin( void );
 bool_t	call_sel_conf_eval_block_end( void );
 bool_t	call_sel_conf_eval_set_num( long token, long n );
