@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.116 2010/01/12 04:09:54 bowkenken Exp $
+* $Id: call.cpp,v 1.128 2011/01/09 01:58:24 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -61,6 +61,10 @@ void	gui_begin( void )
 	gdk_threads_enter();
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	[gMainLock lock];
+#endif // D_IPHONE
+
 #ifdef D_MFC
 #endif // D_MFC
 }
@@ -80,10 +84,47 @@ void	gui_end( void )
 	gdk_threads_leave();
 #endif // D_GTK
 
+#ifdef D_IPHONE
+	[gMainLock unlock];
+#endif // D_IPHONE
+
 #ifdef D_MFC
 #endif // D_MFC
 }
 
+/***************************************************************
+* ưס
+***************************************************************/
+
+void	call_alloc_autorelease_pool( void )
+{
+#ifdef D_IPHONE
+	alloc_autorelease_pool();
+#endif // D_IPHONE
+}
+
+/***************************************************************
+* ưס
+***************************************************************/
+
+void	call_release_autorelease_pool( void )
+{
+#ifdef D_IPHONE
+	release_autorelease_pool();
+#endif // D_IPHONE
+}
+
+/***************************************************************
+* λν
+***************************************************************/
+
+void	call_close_game_gui( void )
+{
+#ifdef	D_ALL_GUI
+	closeGameGui();
+#endif
+}
+
 /***************************************************************
 * ХåեΥå
 ***************************************************************/
@@ -114,7 +155,7 @@ void	key_buf_unlock( void )
 
 bool_t	call_game_thread_create( void *(*func)( void * ) )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef		D_ALL_GUI
 	if( GameThreadCreate( func ) )
 		return TRUE;
 	else
@@ -135,7 +176,7 @@ bool_t	call_game_thread_exit(
 	void *(*func)( void * ), long code
 )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef		D_ALL_GUI
 	if( GameThreadExit( func, code ) )
 		return TRUE;
 	else
@@ -145,13 +186,27 @@ bool_t	call_game_thread_exit(
 	return TRUE;
 }
 
+/***************************************************************
+* ȡǥ쥯ȥ֤
+* return : ȡǥ쥯ȥ
+***************************************************************/
+
+const char	*call_get_home_dir( void )
+{
+#ifdef D_IPHONE
+	return [[NSString stringWithFormat:@"%@/Documents", NSHomeDirectory()] cString];
+#endif // D_IPHONE
+
+	return NULL;
+}
+
 /***************************************************************
 * ޡͭˤ
 ***************************************************************/
 
 void	call_ena_timer( void )
 {
-#ifdef D_GTK
+#if	defined( D_GTK ) || defined( D_IPHONE )
 	ena_timer();
 #endif // D_GTK
 }
@@ -189,7 +244,7 @@ void	call_gui_map_cont_exec_set( bool_t flagExec )
 
 void	call_gui_map_print_stat_bar_hint( void )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
@@ -244,6 +299,70 @@ void	call_gui_menu_wipe( void )
 #endif
 }
 
+/***************************************************************
+* ޥ٥ȤѴ
+* long c : 
+* return : 
+***************************************************************/
+
+long	call_cui_mouse_check_event( long c )
+{
+#ifdef	D_GTK
+	return gCuiMouse.checkEvent( c );
+#endif
+
+	return '\0';
+}
+
+/***************************************************************
+* ޥ٥ȡϥɥ顼ꥻå
+***************************************************************/
+
+void	call_cui_mouse_reset_handler_tab( void )
+{
+#ifdef	D_GTK
+	gCuiMouse.resetHandlerTab();
+#endif
+}
+
+/***************************************************************
+* ϥɥ顼ơ֥ɲ
+* bool flagEnable : ̵ͭե饰
+* long x : åȿûγ X ɸ
+* long y : åȿûγ Y ɸ
+* long w : åȿû
+* long h : åȿûι⤵
+* long n : ϥɥؤΰ ()
+* const char *macro : ϥɥؤΰ (ޥ)
+* bool_t (*funcPoint)( long btn, long n, const char *macro ) : 
+*   ݥȻΥϥɥ
+* bool_t (*funcClick)( long btn, long n, const char *macro ) : 
+*   åΥϥɥ
+* bool_t (*funcScroll)( long btn, long n, const char *macro ) : 
+*   åΥϥɥ
+* return : ϥɥ顼ơֹ֥
+***************************************************************/
+
+long	call_cui_mouse_add_handler(
+	bool_t flagEnable,
+	long x, long y, long w, long h,
+	bool_t (*funcPoint)( long btn, long n, const char *macro ),
+	bool_t (*funcClick)( long btn, long n, const char *macro ),
+	bool_t (*funcScroll)( long btn, long n, const char *macro ),
+	long n,
+	const char *macro
+)
+{
+#ifdef	D_GTK
+	return gCuiMouse.addHandler(
+			flagEnable,
+			x, y, w, h,
+			funcPoint, funcClick, funcScroll,
+			n, macro );
+#endif
+	return '\0';
+}
+
 /***************************************************************
 * ǥեȤܤ˥ޥư
 * long sel_n : 
@@ -682,18 +801,6 @@ void	call_gui_chr_sheet_wipe()
 #endif
 }
 
-/***************************************************************
-* եåǥ쥯ȥ
-* char *dir : եåǥ쥯ȥ
-***************************************************************/
-
-void	call_set_str_dir_sel_graph( char *dir )
-{
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
-	FileList::setStrDirSelGraph( dir );
-#endif
-}
-
 /***************************************************************
 * եåΥ֥å򳫻
 * return : 顼̵ä?
@@ -701,7 +808,7 @@ void	call_set_str_dir_sel_graph( char *dir )
 
 bool_t	call_sel_conf_eval_block_begin( void )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef		D_ALL_GUI
 	if( gSelConf.evalBlockBegin() )
 		return TRUE;
 	else
@@ -718,7 +825,7 @@ bool_t	call_sel_conf_eval_block_begin( void )
 
 bool_t	call_sel_conf_eval_block_end( void )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef		D_ALL_GUI
 	if( gSelConf.evalBlockEnd() )
 		return TRUE;
 	else
@@ -737,7 +844,7 @@ bool_t	call_sel_conf_eval_block_end( void )
 
 bool_t	call_sel_conf_eval_set_num( long token, long n )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef		D_ALL_GUI
 	if( gSelConf.evalSetNum( (GraphConfToken)token, n ) )
 		return TRUE;
 	else
@@ -756,7 +863,7 @@ bool_t	call_sel_conf_eval_set_num( long token, long n )
 
 bool_t	call_sel_conf_eval_set_str( long token, char *str )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef		D_ALL_GUI
 	if( gSelConf.evalSetStr( (GraphConfToken)token, str ) )
 		return TRUE;
 	else
@@ -821,7 +928,7 @@ void	call_sel_mbr_graph_end( void )
 
 void	call_pcg_dun_reset( void )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( !g_flg_gui )
 		return;
 
@@ -839,7 +946,7 @@ void	call_pcg_dun_reset( void )
 
 void	call_pcg_dun_reload_all_mbr( void )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( !g_flg_gui )
 		return;
 
@@ -857,7 +964,7 @@ void	call_pcg_dun_reload_all_mbr( void )
 
 void	call_pcg_dun_draw_turn( bool_t flg_first )
 {
-#if	defined( D_WS ) || defined( D_GTK )
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_IPHONE )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
@@ -904,7 +1011,7 @@ void	call_pcg_dun_redraw( bool_t flgForce )
 	else
 		bFlagForce = false;
 
-#if	defined( D_WS ) || defined( D_GTK )
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_IPHONE )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
@@ -954,7 +1061,7 @@ void	call_pcg_dun_draw(
 	else
 		bFlagForce = false;
 
-#if	defined( D_WS ) || defined( D_GTK )
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_IPHONE )
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
@@ -992,7 +1099,7 @@ void	call_pcg_dun_draw(
 void	call_pcg_dun_set_xx_attack(
 	long kind, void *p )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
@@ -1014,7 +1121,7 @@ void	call_pcg_dun_draw_string(
 	long scrn_x, long scrn_y,
 	const char *s, ... )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	va_list	argptr;
 	static char	buf[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
 	const long	max_len = SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8;
@@ -1048,7 +1155,7 @@ void	call_pcg_dun_draw_vfx(
 	long scrn_x, long scrn_y,
 	long scrn_w, long scrn_h )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
@@ -1070,7 +1177,7 @@ void	call_pcg_dun_draw_vfx(
 
 void	call_pcg_dun_scroll( long map_x, long map_y )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( !g_flg_init )
 		return;
 	if( !g_flg_gui )
@@ -1092,7 +1199,7 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 
 long	call_pcg_dun_get_crsr_width( bool_t flagSub )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	gui_begin();
 
 	long n = gPcgDun.getCrsrWidth( !!flagSub );
@@ -1113,7 +1220,7 @@ long	call_pcg_dun_get_crsr_width( bool_t flagSub )
 
 long	call_pcg_dun_get_crsr_height( bool_t flagSub )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	gui_begin();
 
 	long n = gPcgDun.getCrsrHeight( !!flagSub );
@@ -1135,7 +1242,7 @@ long	call_pcg_dun_get_crsr_height( bool_t flagSub )
 
 long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	bool bFlagPre;
 	if( flagPre )
 		bFlagPre = true;
@@ -1176,7 +1283,7 @@ long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 
 long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	bool bFlagPre;
 	if( flagPre )
 		bFlagPre = true;
@@ -1217,7 +1324,7 @@ long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 
 long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	bool bFlagPre;
 	if( flagPre )
 		bFlagPre = true;
@@ -1258,7 +1365,7 @@ long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 
 long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	bool bFlagPre;
 	if( flagPre )
 		bFlagPre = true;
@@ -1300,7 +1407,7 @@ long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
 
 bool_t	call_pcg_dun_clip_win( long mapX, long mapY, bool_t flg_gui )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( !flg_gui )
 		gui_begin();
 
@@ -1323,7 +1430,7 @@ bool_t	call_pcg_dun_clip_win( long mapX, long mapY, bool_t flg_gui )
 
 bool_t	call_pcg_dun_clip_win_x( long mapX, bool_t flg_gui )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( !flg_gui )
 		gui_begin();
 
@@ -1346,7 +1453,7 @@ bool_t	call_pcg_dun_clip_win_x( long mapX, bool_t flg_gui )
 
 bool_t	call_pcg_dun_clip_win_y( long mapY, bool_t flg_gui )
 {
-#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+#ifdef	D_ALL_GUI
 	if( !flg_gui )
 		gui_begin();
 
@@ -1840,7 +1947,7 @@ void	call_key_check_move_crsr( void )
 
 	gui_begin();
 
-	gKey.CheckMoveCrsr();
+	gKey.checkMoveCrsr();
 
 	gui_end();
 #endif
