@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.87 2009/08/15 06:21:45 bowkenken Exp $
+* $Id: curs.c,v 1.97 2011/01/09 01:58:24 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -58,89 +58,111 @@ static curs_attr_t	g_current_attr;
 check_memory_def( check_memory_curs_c_flg_curs )
 
 /* °Υǥե */
+/* ӽѤ curs_attr_n_t ⽤뤳 */
 
-static curs_attr_t	g_curs_attr[CURS_ATTR_MAX_N] = {
+static curs_attr_t	g_curs_attr[CURS_ATTR_N_MAX_N] = {
 	{ 0, N_MSG_ATTR_NORMAL,
 		COLOR_WHITE, COLOR_BLACK, A_NORMAL, },
-
 	{ 0, N_MSG_ATTR_REV,
 		COLOR_WHITE, COLOR_BLACK, A_REVERSE, },
-
 	{ 0, N_MSG_ATTR_ERR,
 		COLOR_RED, COLOR_BLACK, A_BOLD, },
 
 	{ 0, N_MSG_ATTR_MENU_NORMAL,
 		COLOR_WHITE, COLOR_BLACK, A_NORMAL, },
-
 	{ 0, N_MSG_ATTR_MENU_DIS,
 		COLOR_YELLOW, COLOR_BLACK, A_NORMAL, },
-
 	{ 0, N_MSG_ATTR_MENU_SEL,
 		COLOR_WHITE, COLOR_BLACK, A_REVERSE, },
 
+	{ 0, N_MSG_ATTR_MAP_CRSR,
+		COLOR_GREEN, COLOR_BLACK, A_NORMAL, },
+	{ 0, N_MSG_ATTR_MAP_SQUARE,
+		COLOR_MAGENTA, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_WALL,
+		COLOR_WHITE, COLOR_BLACK, A_NORMAL, },
+	{ 0, N_MSG_ATTR_MAP_FLOOR,
+		COLOR_WHITE, COLOR_BLACK, A_NORMAL, },
+	{ 0, N_MSG_ATTR_MAP_DOOR,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_STAIRS,
+		COLOR_CYAN, COLOR_BLACK, A_REVERSE, },
+	{ 0, N_MSG_ATTR_MAP_TRAP,
+		COLOR_RED, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_MNSTR,
+		COLOR_RED, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_NPC,
+		COLOR_CYAN, COLOR_BLACK, A_NORMAL, },
+	{ 0, N_MSG_ATTR_MAP_PET,
+		COLOR_WHITE, COLOR_BLACK, A_REVERSE, },
+
 	{ 0, N_MSG_ATTR_MAP_ITEM,
 		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
-
-	{ 0, N_MSG_ATTR_MAP_SQUARE,
-		COLOR_CYAN, COLOR_BLACK, A_NORMAL, },
-
-	{ 0, N_MSG_ATTR_MAP_MNSTR,
-		COLOR_RED, COLOR_BLACK, A_BOLD, },
-
-	{ 0, N_MSG_ATTR_MAP_NPC,
-		COLOR_CYAN, COLOR_BLACK, A_NORMAL, },
-
-	{ 0, N_MSG_ATTR_MAP_CRSR,
-		COLOR_GREEN, COLOR_BLACK, A_NORMAL, },
-
-	{ 0, N_MSG_ATTR_FX_MBR_PLUS,
-		COLOR_CYAN, COLOR_BLACK, A_BOLD, },
-
-	{ 0, N_MSG_ATTR_FX_MBR_MINUS,
-		COLOR_RED, COLOR_BLACK, A_BOLD, },
-
-	{ 0, N_MSG_ATTR_FX_MBR_CRTCL,
-		COLOR_RED, COLOR_BLACK, A_REVERSE, },
-
-	{ 0, N_MSG_ATTR_FX_MNSTR_PLUS,
-		COLOR_RED, COLOR_BLACK, A_NORMAL, },
-
-	{ 0, N_MSG_ATTR_FX_MNSTR_MINUS,
-		COLOR_CYAN, COLOR_BLACK, A_NORMAL, },
-
-	{ 0, N_MSG_ATTR_FX_MNSTR_CRTCL,
-		COLOR_CYAN, COLOR_BLACK, A_REVERSE, },
-
-	{ 0, N_MSG_ATTR_VFX,
+	{ 0, N_MSG_ATTR_MAP_ITEM_WPN,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_ARMOR,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_POTION,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_SCROLL,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_STICK,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_ACCE,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_INST,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_LIGHT,
 		COLOR_YELLOW, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_SPIKE,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_FOOD,
+		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_CHEST,
+		COLOR_GREEN, COLOR_BLACK, A_REVERSE, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_RARE_GOODS,
+		COLOR_GREEN, COLOR_BLACK, A_REVERSE, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_BONE,
+		COLOR_WHITE, COLOR_BLACK, A_NORMAL, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_COIN,
+		COLOR_GREEN, COLOR_BLACK, A_REVERSE, },
+	{ 0, N_MSG_ATTR_MAP_ITEM_JUNK,
+		COLOR_WHITE, COLOR_BLACK, A_NORMAL, },
 
 	{ 0, N_MSG_ATTR_MBR_1,
 		COLOR_RED, COLOR_BLACK, A_REVERSE, },
-
 	{ 0, N_MSG_ATTR_MBR_2,
 		COLOR_GREEN, COLOR_BLACK, A_REVERSE, },
-
 	{ 0, N_MSG_ATTR_MBR_3,
 		COLOR_BLUE, COLOR_BLACK, A_BOLD | A_REVERSE, },
-
 	{ 0, N_MSG_ATTR_MBR_4,
 		COLOR_CYAN, COLOR_BLACK, A_REVERSE, },
-
 	{ 0, N_MSG_ATTR_MBR_5,
 		COLOR_MAGENTA, COLOR_BLACK, A_REVERSE, },
-
 	{ 0, N_MSG_ATTR_MBR_6,
 		COLOR_YELLOW, COLOR_BLACK, A_REVERSE, },
 
+	{ 0, N_MSG_ATTR_FX_MBR_PLUS,
+		COLOR_CYAN, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_FX_MBR_MINUS,
+		COLOR_RED, COLOR_BLACK, A_BOLD, },
+	{ 0, N_MSG_ATTR_FX_MBR_CRTCL,
+		COLOR_RED, COLOR_BLACK, A_REVERSE, },
+	{ 0, N_MSG_ATTR_FX_MNSTR_PLUS,
+		COLOR_RED, COLOR_BLACK, A_NORMAL, },
+	{ 0, N_MSG_ATTR_FX_MNSTR_MINUS,
+		COLOR_CYAN, COLOR_BLACK, A_NORMAL, },
+	{ 0, N_MSG_ATTR_FX_MNSTR_CRTCL,
+		COLOR_CYAN, COLOR_BLACK, A_REVERSE, },
+	{ 0, N_MSG_ATTR_VFX,
+		COLOR_YELLOW, COLOR_BLACK, A_BOLD, },
+
 	{ 0, N_MSG_ATTR_HEAT,
 		COLOR_RED, COLOR_BLACK, A_BOLD, },
-
 	{ 0, N_MSG_ATTR_COLD,
 		COLOR_BLUE, COLOR_BLACK, A_BOLD, },
-
 	{ 0, N_MSG_ATTR_MIND,
 		COLOR_GREEN, COLOR_BLACK, A_BOLD, },
-
 	{ 0, N_MSG_ATTR_ACID,
 		COLOR_YELLOW, COLOR_BLACK, A_BOLD, },
 };
@@ -184,7 +206,7 @@ bool_t	init_curs_color( void )
 
 	if( g_flg_gui && !g_flg_cui ){
 		flg_color = TRUE;
-		for( n = 0; n < CURS_ATTR_MAX_N; n++ ){
+		for( n = 0; n < CURS_ATTR_N_MAX_N; n++ ){
 			short	pair_n;
 
 			pair_n = n + 1;
@@ -217,7 +239,7 @@ bool_t	init_curs_color( void )
 #endif	/* HAVE_NCURSES_H || HAVE_CURSES_H */
 
 	flg_color = TRUE;
-	for( n = 0; n < CURS_ATTR_MAX_N; n++ ){
+	for( n = 0; n < CURS_ATTR_N_MAX_N; n++ ){
 		short	pair_n;
 
 		pair_n = n + 1;
@@ -976,6 +998,48 @@ long	get_screen_row( void )
 	return SCREEN_HEIGHT;
 }
 
+/***************************************************************
+* ޥåפβʸĴ٤
+* return : ʸ
+***************************************************************/
+
+long	get_map_col( void )
+{
+	if( chk_flg_resize_map() ){
+		long	n;
+
+		n = get_screen_col();
+		n -= SCREEN_WIDTH - (WIN_MAP_DRAW_MAX_X + 1);
+		return n;
+	} else {
+		return( WIN_MAP_DRAW_WIDTH );
+	}
+
+	return 1;
+}
+
+/***************************************************************
+* ޥåפνĹԿĴ٤
+* return : ĹԿ
+***************************************************************/
+
+long	get_map_row( void )
+{
+	if( chk_flg_resize_map() ){
+		long	n;
+
+		n = get_screen_row();
+		n -= 1;
+		n -= get_screen_size_message();
+		n -= get_stat_bar_row();
+		return n;
+	} else {
+		return( WIN_MAP_DRAW_HEIGHT );
+	}
+
+	return 1;
+}
+
 /***************************************************************
 * åβʸĴ٤
 * return : ʸ
@@ -996,51 +1060,35 @@ long	get_message_row( void )
 	if( chk_flg_resize_map() ){
 		return get_screen_size_message();
 	} else {
-		return( get_screen_row() - (WIN_MAP_DRAW_HEIGHT + 1) );
+		long	n;
+
+		n = get_screen_row();
+		n -= WIN_MAP_DRAW_HEIGHT + 1;
+		n -= get_stat_bar_row();
+		return n;
 	}
 
 	return 1;
 }
 
 /***************************************************************
-* ޥåפβʸĴ٤
+* ơСβʸĴ٤
 * return : ʸ
 ***************************************************************/
 
-long	get_map_col( void )
+long	get_stat_bar_col( void )
 {
-	if( chk_flg_resize_map() ){
-		long	n;
-
-		n = WIN_MAP_DRAW_MAX_X + 1;
-		n = SCREEN_WIDTH - n;
-		n = get_screen_col() - n;
-		return n;
-	} else {
-		return( WIN_MAP_DRAW_MAX_X + 1 );
-	}
-
-	return 1;
+	return get_screen_col() - 1;
 }
 
 /***************************************************************
-* ޥåפνĹԿĴ٤
+* ơСνĹԿĴ٤
 * return : ĹԿ
 ***************************************************************/
 
-long	get_map_row( void )
+long	get_stat_bar_row( void )
 {
-	if( chk_flg_resize_map() ){
-		long	n;
-
-		n = get_screen_size_message() + 1;
-		n = get_screen_row() - n;
-		return n;
-	} else {
-		return( WIN_MAP_DRAW_MAX_Y + 1 );
-	}
-
-	return 1;
+	return calc_stat_bar_line_n();
 }
 
 /***************************************************************
