@@ -50,14 +50,29 @@ bool_t	chk_msg_mul_line( void );
 long	get_ls_msg_n( void );
 void	draw_ls_msg( long n );
 ls_msg_t	*get_ls_msg( long idx );
+long	add_scroll_msg_idx( long add );
+void	draw_stat_bar( void );
+long	calc_stat_bar_line_n( void );
+bool_t	get_flg_stat_bar_hint_chr( void );
+void	set_flg_stat_bar_hint_chr( bool_t flg );
+bool_t	get_flg_stat_bar_hint_obj( void );
+void	set_flg_stat_bar_hint_obj( bool_t flg );
 void	print_str( long scrn_x, long scrn_y, const char *s, ... );
-bool_t	print_vfx( long scrn_x, long scrn_y, const char *s, ... );
-bool_t	print_vfx_cui( long scrn_x, long scrn_y, const char *s, ... );
+bool_t	print_vfx(
+	bool_t flg_gui, long scrn_x, long scrn_y, const char *s, ...
+);
+bool_t	print_vfx_cui(
+	bool_t flg_gui, long scrn_x, long scrn_y, const char *s, ...
+);
 void	wipe_vfx( long map_x, long map_y, long dx, long dy );
 bool_t	set_redraw_every_turn( bool_t flg );
 bool_t	chk_redraw_every_turn( void );
 void	wipe_all( void );
 void	redraw_all( void );
+void	set_cui_mouse_add_handler_map( void );
+void	set_cui_mouse_add_handler_msg( void );
+void	set_cui_mouse_add_handler_stat( void );
+void	set_cui_mouse_add_handler_mbr_stat( long mbr_n );
 void	draw_map( long map_x, long map_y, long dx, long dy );
 void	draw_map_force( long map_x, long map_y, long dx, long dy );
 void	draw_map_sub(
@@ -70,6 +85,12 @@ void	redraw_map_force( void );
 void	redraw_map_sub( bool_t flgForce );
 void	wipe_map( void );
 void	force_clr_redraw_map( void );
+bool_t	cb_cui_mouse_scroll_map(
+	long scroll_dir, long n, const char *macro
+);
+bool_t	cb_cui_mouse_scroll_msg(
+	long scroll_dir, long n, const char *macro
+);
 void	draw_party( void );
 void	draw_mbr( mbr_t *p );
 void	draw_square( void );
@@ -84,21 +105,69 @@ void	draw_door( long dr_n );
 void	draw_item( item_t *p );
 void	draw_trap( trap_t *p );
 void	draw_menu( draw_menu_t *data );
+bool_t	cb_cui_mouse_point_menu( long btn, long n, const char *macro );
+bool_t	cb_cui_mouse_click_menu( long btn, long n, const char *macro );
+bool_t	cb_cui_mouse_click_menu_page( long btn, long n, const char *macro );
+bool_t	cb_cui_mouse_click_menu_outside(
+	long btn, long n, const char *macro
+);
+void	set_cui_mouse_add_handler_common_scroll( void );
+bool_t	cb_cui_mouse_point_dummy(
+	long btn, long n, const char *macro
+);
+bool_t	cb_cui_mouse_click_common_scroll(
+	long btn, long n, const char *macro
+);
+bool_t	cb_cui_mouse_scroll_common_scroll(
+	long scroll_dir, long n, const char *macro
+);
 void	draw_menu_num( long figure, long sel_n, char num[] );
+bool_t	cb_cui_mouse_point_menu_num( long btn, long n, const char *macro );
+bool_t	cb_cui_mouse_click_menu_num( long btn, long n, const char *macro );
+bool_t	cb_cui_mouse_click_menu_num_sel(
+	long btn, long n, const char *macro
+);
+bool_t	cb_cui_mouse_scroll_menu_num_sel(
+	long scroll_dir, long n, const char *macro
+);
+bool_t	get_flg_cui_mouse_scroll_menu_num_is_sel( void );
+void	set_flg_cui_mouse_scroll_menu_num_is_sel( bool_t flg );
+bool_t	get_flg_cui_mouse_r_click_menu_num_is_cancel( void );
+void	set_flg_cui_mouse_r_click_menu_num_is_cancel( bool_t flg );
 char	*get_str_open_win_item( char *kind );
 char	*get_str_branch( char *kind );
 bool_t	wipe_menu( void );
 void	draw_all_mbr_stat( void );
 void	draw_mbr_stat( mbr_t *mbr );
 void	draw_misc_stat( void );
+void	switch_stat_mode( long add );
+stat_mode_t	get_stat_mode( void );
+bool_t	cb_cui_mouse_click_stat( long btn, long n, const char *macro );
+bool_t	cb_cui_mouse_click_switch_stat(
+	long btn, long n, const char *macro
+);
 const char	*get_stat_dun_lev_str( void );
 void	draw_misc_stat_time( bool_t flg_force );
+gui_vfx_t	*alloc_gui_vfx_bash( bool_t flg_crtcl );
+gui_vfx_t	*alloc_gui_vfx_arw( long dir_n );
+gui_vfx_t	*alloc_gui_vfx_throw_item( char mjr, char mnr );
+gui_vfx_t	*alloc_gui_vfx_spell( resi_kind_t resi );
+gui_vfx_t	*alloc_gui_vfx_blast( blast_kind_t blast );
+gui_vfx_t	*alloc_gui_vfx_ninja( spell_kind_t spell );
+gui_vfx_t	*alloc_gui_vfx( void );
+void	free_gui_vfx( gui_vfx_t *vfx );
+void	clr_gui_vfx_all( void );
+void	clr_gui_vfx( long map_x, long map_y );
+void	set_gui_vfx( long map_x, long map_y, gui_vfx_t *vfx );
+gui_vfx_t	*get_gui_vfx( long map_x, long map_y );
+long	calc_dir_n( const pos_t *bgn, const pos_t *end );
 bool_t	vfx_spell( spell_tab_t *tab, long arw_n, pos_t bgn[], pos_t end[] );
 void	vfx_spell_typhoon( void );
 void	vfx_spell_conflagration( long arw_n, pos_t end[] );
 bool_t	vfx_spell_conflagration_sub( long x, long y, long height );
 void	vfx_spell_earthquake( void );
 void	vfx_spell_thunder( long arw_n, pos_t end[] );
+void	draw_gui_vfx_spell_thunder( gui_vfx_t *gui_vfx, pos_t *pos );
 void	vfx_spell_inundation( void );
 void	vfx_hit( chr_t *chr, long x, long y );
 void	vfx_crtcl( chr_t *chr, long x, long y );
@@ -109,14 +178,18 @@ void	set_vfx_attr_n( curs_attr_n_t n );
 void	vfx_arw(
 	chr_kind_t kind,
 	pos_t bgn[], pos_t end[],
-	char c, long len );
+	gui_vfx_t *gui_vfx,
+	char c, long len
+);
 void	vfx_arw_line(
 	pos_t bgn[], pos_t end[],
+	gui_vfx_t *gui_vfx,
 	const char *str, long len,
 	long frame, long clr_frame, bool_t flg_clr
 );
 void	vfx_arw_mul_line(
 	long arw_n, pos_t bgn[], pos_t end[],
+	gui_vfx_t *gui_vfx,
 	const char *str, long len,
 	long frame, long clr_frame, bool_t flg_clr
 );
@@ -136,25 +209,49 @@ void	draw_lev_up( long map_x, long map_y, long n, chr_t *chr );
 void	draw_blast(
 	chr_kind_t kind,
 	long map_x, long map_y,
-	blast_t *p, char *str
+	blast_t *p,
+	gui_vfx_t *gui_vfx,
+	char *str
 );
 void	draw_blast_cui(
 	chr_kind_t kind,
 	long map_x, long map_y,
-	blast_t *p, char *str
+	blast_t *p,
+	gui_vfx_t *gui_vfx,
+	char *str
 );
 void	draw_blast_sub(
 	bool_t flg_cui,
 	chr_kind_t kind,
 	long map_x, long map_y,
-	blast_t *p, char *str
+	blast_t *p,
+	gui_vfx_t *gui_vfx,
+	char *str
 );
 void	draw_request( request_t *req );
 void	draw_words( const char *name, const char *words, ... );
-void	redraw_mbr_data( mbr_t *org, mbr_t *mbr, long page_n );
-void	draw_mbr_data_all( mbr_t *org, mbr_t *mbr, long page_n );
-void	draw_mbr_data_all_cui( mbr_t *org, mbr_t *mbr, long page_n );
-void	draw_mbr_data( mbr_t *org, mbr_t *mbr, data_n_t n, bool_t flg_rev );
+bool_t	cb_cui_mouse_click_words( long btn, long n, const char *macro );
+void	redraw_mbr_data(
+	mbr_t *org, mbr_t *mbr,
+	long page_n, mbr_data_edit_kind_t edit_kind
+);
+void	draw_mbr_data_all(
+	mbr_t *org, mbr_t *mbr,
+	long page_n, mbr_data_edit_kind_t edit_kind
+);
+void	draw_mbr_data_all_cui(
+	mbr_t *org, mbr_t *mbr,
+	long page_n, mbr_data_edit_kind_t edit_kind
+);
+void	draw_mbr_data(
+	mbr_t *org, mbr_t *mbr,
+	data_n_t n, bool_t flg_rev,
+	mbr_data_edit_kind_t edit_kind,
+	bool_t flg_all
+);
+bool_t	cb_cui_mouse_point_mbr_data( long btn, long n, const char *macro );
+bool_t	cb_cui_mouse_click_mbr_data( long btn, long n, const char *macro );
+long	calc_mbr_data_idx( data_n_t next_n, data_n_t cur_n );
 data_n_t	next_mbr_data(
 	long page_n, data_n_t n, long d,
 	mbr_data_edit_kind_t edit_kind
@@ -171,16 +268,21 @@ void	draw_edit_class_all(
 );
 void	draw_edit_class(
 	class_t *org, class_t *dst, edit_class_t n,
-	bool_t flg_sel, bool_t flg_sel_add
+	bool_t flg_sel, bool_t flg_sel_add,
+	bool_t flg_all
 );
+bool_t	cb_cui_mouse_point_edit_class( long btn, long n, const char *macro );
+bool_t	cb_cui_mouse_click_edit_class( long btn, long n, const char *macro );
 void	draw_edit_skill_all(
 	class_t *org, class_t *dst,
 	edit_skill_t sel_n
 );
 void	draw_edit_skill(
 	class_t *org, class_t *dst, edit_skill_t n,
-	bool_t flg_sel
+	bool_t flg_sel, bool_t flg_all
 );
+bool_t	cb_cui_mouse_point_edit_skill( long btn, long n, const char *macro );
+bool_t	cb_cui_mouse_click_edit_skill( long btn, long n, const char *macro );
 bool_t	gets_class_name( char *name );
 bool_t	gets_item_alias( char *name );
 bool_t	gets_auto_mark_info( char *name );
@@ -195,7 +297,7 @@ void	game_gets_gui_sub( const char *ttl, char *s, long len );
 void	pick_cntrl_str( char *s );
 void	set_crsr( long x, long y );
 void	reset_crsr( void );
-void	draw_crsr( void );
+void	draw_main_crsr( void );
 void	draw_sub_crsr( void );
 pos_t	*get_map_draw_pos( void );
 pos_t	*get_map_draw_pos_gui( void );
