@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.h,v 1.40 2008/09/06 14:49:19 bowkenken Exp $
+* $Id: dun.h,v 1.55 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DUN_H
@@ -47,8 +47,17 @@
 /* ϲκ糬 */
 #define	DUN_MAX_LEV_BASE	10000
 
-/* ܥŪи볬ؿ */
+/* ƥơγؿ (ܥŪ˽и볬ؿ) */
 #define	DUN_LEV_BOSS	10
+/* ơ */
+#define	STAGE_MAX_N	10
+/* ơ롼פ볬 */
+#define	DUN_LEV_LOOP	(DUN_LEV_BOSS * STAGE_MAX_N)
+
+/* 饹ܥγ */
+#define	DUN_LEV_LAST_BOSS	-99999
+/* 饹ܥؤγʤи볬 */
+#define	DUN_LEV_LAST_BOSS_STAIRS	DUN_LEV_LOOP
 
 /***************************************************************
 * ޥåפι
@@ -86,6 +95,7 @@ typedef unsigned long	flg_map_t;
 
 #define	FLG_MAP_OBJ_FIND	(1 << 0)	/* ȯ */
 #define	FLG_MAP_OBJ_PASS	(1 << 1)	/* ̹Բ */
+#define	FLG_MAP_OBJ_LOOK	(1 << 2)	/* ̤ */
 #define	FLG_MAP_OBJ_LOOK_FLOOR	(1 << 4)	/* ˸ */
 #define	FLG_MAP_OBJ_LOOK_WALL	(1 << 5)	/* ɤ˸ */
 
@@ -113,9 +123,21 @@ typedef unsigned long	flg_map_t;
 #define	FACE_MNR_WALL	'#'
 #define	FACE_MNR_STATUE	'@'
 #define	FACE_MNR_STREETLAMP	'*'
+#define	FACE_MNR_BOOT_UNIT	'&'
 
 #define	FACE_MJR_FLOOR	'.'
 #define	FACE_MNR_FLOOR	' '
+#define	FACE_MNR_HOLE	'^'
+
+#define	FACE_MJR_WATER	'~'
+#define	FACE_MNR_PUDDLE	'.'
+#define	FACE_MNR_SHALLOWS	' '
+#define	FACE_MNR_OFFING	'~'
+#define	FACE_MNR_LAVA	'^'
+
+#define	FACE_MJR_MOUNTAIN	'/'
+#define	FACE_MNR_MOUNTAIN	'\\'
+#define	FACE_MNR_HILL	')'
 
 #define	FACE_MJR_ITEM	'$'
 
@@ -145,6 +167,8 @@ typedef unsigned long	flg_map_t;
 #define	FACE_MNR_STAIRS_UP	'u'
 #define	FACE_MJR_STAIRS_DOWN	'>'
 #define	FACE_MNR_STAIRS_DOWN	'd'
+#define	FACE_MJR_STAIRS_LAST_BOSS	'>'
+#define	FACE_MNR_STAIRS_LAST_BOSS	'X'
 
 #define	FACE_MJR_TRAP	'^'
 #define	FACE_MNR_TRAP_SLEEP	's'
@@ -225,6 +249,7 @@ typedef struct {
 ***************************************************************/
 
 struct chr_t;
+struct gui_vfx_t;
 
 typedef struct {
 	/* ֥ȤΥ쥤䡼 */
@@ -233,6 +258,11 @@ typedef struct {
 	map_t	chr;
 	/* 쥤䡼 */
 	map_t	total;
+	/* VFX Υ쥤䡼 */
+	char	vfx[MAP_MAX_Y][MAP_MAX_X * 2];
+	/* GUI VFX Υ쥤䡼 */
+	struct gui_vfx_t	*gui_vfx[MAP_MAX_Y][MAP_MAX_X];
+
 	/*  */
 	sect_t	sect[MAP_MAX_Y][MAP_MAX_X];
 
@@ -246,6 +276,8 @@ typedef struct {
 
 	/* ɽ° */
 	curs_attr_t	attr[MAP_MAX_Y][MAP_MAX_X];
+	/* VFX° */
+	curs_attr_t	attr_vfx[MAP_MAX_Y][MAP_MAX_X * 2];
 } all_map_t;
 
 /***************************************************************
