@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.171 2010/05/29 14:37:00 bowkenken Exp $
+* $Id: fight.c,v 1.174 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1163,6 +1163,8 @@ bool_t	fight_x_1(
 	flg_stat_t	stat;
 	item_t	*eq;
 	pos_t	bgn, end;
+	gui_vfx_t	*gui_vfx;
+	long	dir_n;
 	bool_t	flg_crtcl, flg_ninja_crtcl;
 	bool_t	flg_dead;
 	bool_t	flg_d_null;
@@ -1170,8 +1172,9 @@ bool_t	fight_x_1(
 	bool_t	flg_serious;
 	bool_t	flg_err_range;
 	bool_t	flg_catch_food;
-	char	mjr;
+	char	mjr, mnr;
 	item_t	arw;
+	wpn_tab_t	*bow_tab, *arw_tab;
 	sound_kind_t	sk;
 
 	if( attack == NULL )
@@ -1371,6 +1374,8 @@ bool_t	fight_x_1(
 	end.y = o_p->trgt.true_y;
 
 	mjr = MNSTR_THROW_MJR;
+	mnr = FACE_MNR_NULL;
+	gui_vfx = NULL;
 	if( attack->flg_throw ){
 		sound_kind_t	sk;
 
@@ -1381,11 +1386,36 @@ bool_t	fight_x_1(
 		else
 			sk = SOUND_KIND_NULL;
 		call_game_sound_play( sk, 1 );
+	}
+
+	if( attack->flg_throw && (eq != NULL) ){
+		if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_WPN )
+			bow_tab = eq[EQUIP_KIND_BOW].tab.wpn;
+		else
+			bow_tab = NULL;
+		if( eq[EQUIP_KIND_ARW].kind == ITEM_KIND_WPN )
+			arw_tab = eq[EQUIP_KIND_ARW].tab.wpn;
+		else
+			arw_tab = NULL;
+
+		mjr = get_item_mjr( &(eq[EQUIP_KIND_ARW]) );
+		mnr = get_item_mnr( &(eq[EQUIP_KIND_ARW]) );
+		dir_n = calc_dir_n( &bgn, &end );
+
+		if( chk_dagger( arw_tab ) || chk_bow( arw_tab, bow_tab ) )
+			gui_vfx = alloc_gui_vfx_arw( dir_n );
+		else
+			gui_vfx = alloc_gui_vfx_throw_item( mjr, mnr );
 
 		/* ꤲʪ */
-		if( (o_k == CHR_KIND_MBR) && (eq != NULL) )
-			mjr = get_item_mjr( &(eq[EQUIP_KIND_ARW]) );
-		vfx_arw( o_k, &bgn, &end, mjr, ANIM_ARW_LEN );
+		vfx_arw( o_k, &bgn, &end, gui_vfx, mjr, ANIM_ARW_LEN );
+	} else if( attack->flg_throw && (eq == NULL) ){
+		/* ꤲʪ */
+		mjr = MNSTR_THROW_MJR;
+		dir_n = calc_dir_n( &bgn, &end );
+		gui_vfx = alloc_gui_vfx_arw( dir_n );
+
+		vfx_arw( o_k, &bgn, &end, gui_vfx, mjr, ANIM_ARW_LEN );
 	}
 
 	/* ɸ¦Υǡ */
@@ -1536,7 +1566,8 @@ bool_t	fight_x_1(
 
 		if( chk_come_back_arw( (mbr_t *)o_p ) ){
 			/* ֡Τ褦äƤ */
-			vfx_arw( o_k, &end, &bgn, mjr, ANIM_ARW_LEN );
+			vfx_arw( o_k, &end, &bgn, gui_vfx,
+					mjr, ANIM_ARW_LEN );
 		} else {
 			/*  */
 			dec_throw( (mbr_t *)o_p, TRUE, d_x, d_y );
@@ -1943,9 +1974,12 @@ bool_t	spell_attack(
 	/* и */
 
 	if( flg_stick ){
+		gui_vfx_t	*gui_vfx;
 		char	mjr = '*';
 
-		vfx_arw( o_p->kind, &o_pos, &d_pos, mjr, ANIM_ARW_LEN );
+		gui_vfx = alloc_gui_vfx_spell( resi );
+		vfx_arw( o_p->kind, &o_pos, &d_pos, gui_vfx,
+				mjr, ANIM_ARW_LEN );
 	}
 
 	/* ޡ饹 */
@@ -2477,12 +2511,13 @@ bool_t	chk_magic_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 
 	if( !chk_flg( d_p->flg_chr, FLG_CHR_MAGIC_PROTECT ) )
 		return FALSE;
-	if( !is_mbr( o_p ) )
-		return FALSE;
 
 	do {
 		item_t	*eq;
 
+		if( !is_mbr( o_p ) )
+			break;
+
 		eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
 		if( eq == NULL )
 			break;
