@@ -93,6 +93,7 @@ bool_t	read_scroll_pow_up_armor_def( chr_t *chr );
 bool_t	read_scroll_pow_up_armor_crtcl( chr_t *chr );
 bool_t	read_scroll_pow_up_armor_ac( chr_t *chr );
 bool_t	read_scroll_protect_armor( chr_t *chr );
+bool_t	read_scroll_boomerang( chr_t *chr );
 bool_t	read_scroll_remove_curse( chr_t *chr );
 bool_t	read_scroll_recall( void );
 void	read_scroll_nin( chr_t *chr, scroll_kind_t kind );
@@ -104,8 +105,10 @@ bool_t	fx_darkness( long x, long y );
 bool_t	fx_knock( door_t *door );
 bool_t	fx_lock( door_t *door );
 bool_t	fx_disarm_trap( trap_t *trap, chr_t *chr );
+bool_t	fx_short_teleport_party( long bx, long by );
 bool_t	fx_teleport_party_charge( void );
 bool_t	fx_teleport_party( void );
+bool_t	short_teleport_party( long bx, long by );
 bool_t	teleport_party_charge( void );
 bool_t	chk_teleport_party( void );
 bool_t	teleport_party( void );
@@ -123,6 +126,7 @@ bool_t	fx_detect_door( chr_t *chr );
 bool_t	fx_detect_trap( chr_t *chr );
 bool_t	fx_detect_mnstr( chr_t *chr );
 bool_t	fx_darkvision( chr_t *chr );
+bool_t	fx_escape( long bx, long by );
 bool_t	fx_sanctuary( chr_t *chr, abl_kind_t abl );
 bool_t	fx_weak_attack(
 	chr_t *o_p, trgt_kind_t trgt_kind, void *d_p,
@@ -202,6 +206,7 @@ bool_t	fx_pow_up_armor_def( mbr_t *mbr );
 bool_t	fx_pow_up_armor_crtcl( mbr_t *mbr );
 bool_t	fx_pow_up_armor_ac( mbr_t *mbr );
 bool_t	fx_protect_armor( mbr_t *mbr );
+bool_t	fx_boomerang( mbr_t *mbr );
 bool_t	pow_up_wpn_hit( item_t *wpn );
 bool_t	pow_up_wpn_crtcl( item_t *wpn );
 bool_t	pow_up_wpn_dam( item_t *wpn );
