@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-conf.c,v 1.27 2009/09/11 15:46:19 bowkenken Exp $
+* $Id: gf-conf.c,v 1.37 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -70,7 +70,7 @@ bool_t	load_game_conf( void )
 
 	/* СΥå */
 
-	if( !chk_ver_old( &ver,
+	if( chk_ver_new( &ver,
 			GAME_CONF_VER_MJR,
 			GAME_CONF_VER_MNR,
 			GAME_CONF_VER_PAT ) ){
@@ -100,7 +100,7 @@ bool_t	load_game_conf( void )
 
 	/* Сʥå */
 
-	if( chk_ver_old( &ver, 1, 0, 14 ) )
+	if( chk_ver_old( &ver, 1, 0, 15 ) )
 		ver_up_game_conf_1_0_15();
 
 	/* ե򥯥 */
@@ -385,6 +385,12 @@ bool_t	load_game_conf_set_val(
 	} else if( strcmp( id, "screen_resize_map" ) == 0 ){
 		return load_game_conf_screen_resize_map( id, val );
 
+	} else if( strcmp( id, "cursor_number_main" ) == 0 ){
+		return load_game_conf_cursor_number_main( id, val );
+
+	} else if( strcmp( id, "cursor_number_sub" ) == 0 ){
+		return load_game_conf_cursor_number_sub( id, val );
+
 	} else if( strcmp( id, "clear_key_buffer_every" ) == 0 ){
 		return load_game_conf_clr_key_buf_every( id, val );
 
@@ -400,9 +406,24 @@ bool_t	load_game_conf_set_val(
 	} else if( strcmp( id, "multiple_message_line" ) == 0 ){
 		return load_game_conf_mul_line( id, val );
 
+	} else if( strcmp( id, "status_bar_hint_character" ) == 0 ){
+		return load_game_conf_stat_bar_hint_chr( id, val );
+
+	} else if( strcmp( id, "status_bar_hint_object" ) == 0 ){
+		return load_game_conf_stat_bar_hint_obj( id, val );
+
 	} else if( strcmp( id, "move_cursor_to_default" ) == 0 ){
 		return load_game_conf_move_crsr_dflt( id, val );
 
+	} else if( strcmp( id, "double_click_wait" ) == 0 ){
+		return load_game_conf_double_click_wait( id, val );
+
+	} else if( strcmp( id, "music_volume" ) == 0 ){
+		return load_game_conf_music_volume( id, val );
+
+	} else if( strcmp( id, "sound_volume" ) == 0 ){
+		return load_game_conf_sound_volume( id, val );
+
 	} else if( strcmp( id, "joystick_number" ) == 0 ){
 		return load_game_conf_joystick_number( id, val );
 
@@ -445,6 +466,9 @@ bool_t	load_game_conf_set_val(
 	} else if( strcmp( id, "attribute_bold" ) == 0 ){
 		return load_game_conf_attribute_bold( id, val );
 
+	} else if( strcmp( id, "audio_buffer_size" ) == 0 ){
+		return load_game_conf_audio_buf_siz( id, val );
+
 	} else if( strcmp( id, "gnome" ) == 0 ){
 		return load_game_conf_gnome( id, val );
 
@@ -794,6 +818,36 @@ bool_t	load_game_conf_scroll( char *id, char *str )
 	return TRUE;
 }
 
+/***************************************************************
+* եΥᥤ󡦥롦ѥֹ
+* char *id : ̻
+* long val : ѥֹ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_cursor_number_main( char *id, long val )
+{
+	set_main_crsr_ptn_n( val );
+	reset_crsr_ptn();
+
+	return TRUE;
+}
+
+/***************************************************************
+* եΥ֡롦ѥֹ
+* char *id : ̻
+* long val : ѥֹ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_cursor_number_sub( char *id, long val )
+{
+	set_sub_crsr_ptn_n( val );
+	reset_crsr_ptn();
+
+	return TRUE;
+}
+
 /***************************************************************
 * 祤ƥåμ
 * char *id : ̻
@@ -881,6 +935,34 @@ bool_t	load_game_conf_mul_line( char *id, long val )
 	return TRUE;
 }
 
+/***************************************************************
+* եΥơСΥ饯ΥҥȤɽ뤫
+* char *id : ̻
+* long val : ɽ뤫?
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_stat_bar_hint_chr( char *id, long val )
+{
+	set_flg_stat_bar_hint_chr( (bool_t)val );
+
+	return TRUE;
+}
+
+/***************************************************************
+* եΥơСΥ֥ȤΥҥȤɽ뤫
+* char *id : ̻
+* long val : ɽ뤫?
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_stat_bar_hint_obj( char *id, long val )
+{
+	set_flg_stat_bar_hint_obj( (bool_t)val );
+
+	return TRUE;
+}
+
 /***************************************************************
 * ˥塼Υǥեȹܤإưư뤫
 * char *id : ̻
@@ -895,6 +977,50 @@ bool_t	load_game_conf_move_crsr_dflt( char *id, long val )
 	return TRUE;
 }
 
+/***************************************************************
+* ֥롦åδֳ֤
+* char *id : ̻
+* long val : ֥롦åδֳ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_double_click_wait( char *id, long val )
+{
+	set_cui_mouse_double_click_msec( val );
+
+	return TRUE;
+}
+
+/***************************************************************
+* BGM β̤
+* char *id : ̻
+* long val : 
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_music_volume( char *id, long val )
+{
+	set_music_volume_rate( val );
+	call_game_music_set_volume( get_music_volume_rate() );
+
+	return TRUE;
+}
+
+/***************************************************************
+* SE β̤
+* char *id : ̻
+* long val : 
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_sound_volume( char *id, long val )
+{
+	set_sound_volume_rate( val );
+	call_game_sound_set_volume( get_sound_volume_rate() );
+
+	return TRUE;
+}
+
 /***************************************************************
 * 祤ƥåֹ
 * char *id : ̻
@@ -909,10 +1035,24 @@ bool_t	load_game_conf_joystick_number( char *id, long val )
 	return TRUE;
 }
 
+/***************************************************************
+* եβХåե
+* char *id : ̻
+* long val : Хåե
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_audio_buf_siz( char *id, long val )
+{
+	g_audio_buf_siz = val;
+
+	return TRUE;
+}
+
 /***************************************************************
 * ե GNOME 
 * char *id : ̻
-* long val : ɸޤϥ
+* long val : ɥޥ͡㤬 GNOME ?
 * return : 顼̵ä?
 ***************************************************************/
 
@@ -1072,24 +1212,118 @@ bool_t	load_game_conf_color_name( char *id, char *name )
 		g_crnt_attr_n = CURS_ATTR_N_NORMAL;
 	if( strcmp( name, "rev" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_REV;
+	if( strcmp( name, "reverse" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_REV;
 	if( strcmp( name, "err" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_ERR;
+	if( strcmp( name, "error" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_ERR;
+
 	if( strcmp( name, "menu_normal" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_MENU_NORMAL;
 	if( strcmp( name, "menu_dis" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_MENU_DIS;
+	if( strcmp( name, "menu_disable" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MENU_DIS;
 	if( strcmp( name, "menu_sel" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_MENU_SEL;
-	if( strcmp( name, "map_item" ) == 0 )
-		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM;
+	if( strcmp( name, "menu_select" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MENU_SEL;
+
+	if( strcmp( name, "map_crsr" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_CRSR;
+	if( strcmp( name, "map_cursor" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_CRSR;
 	if( strcmp( name, "map_square" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_MAP_SQUARE;
+	if( strcmp( name, "map_anchor" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_SQUARE;
+	if( strcmp( name, "map_wall" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_WALL;
+	if( strcmp( name, "map_floor" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_FLOOR;
+	if( strcmp( name, "map_door" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_DOOR;
+	if( strcmp( name, "map_stairs" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_STAIRS;
+	if( strcmp( name, "map_trap" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_TRAP;
 	if( strcmp( name, "map_mnstr" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_MAP_MNSTR;
+	if( strcmp( name, "map_monster" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_MNSTR;
 	if( strcmp( name, "map_npc" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_MAP_NPC;
-	if( strcmp( name, "map_crsr" ) == 0 )
-		g_crnt_attr_n = CURS_ATTR_N_MAP_CRSR;
+	if( strcmp( name, "map_pet" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_PET;
+
+	if( strcmp( name, "map_item" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM;
+	if( strcmp( name, "map_item_wpn" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_WPN;
+	if( strcmp( name, "map_item_weapon" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_WPN;
+	if( strcmp( name, "map_item_armor" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_ARMOR;
+	if( strcmp( name, "map_item_potion" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_POTION;
+	if( strcmp( name, "map_item_scroll" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_SCROLL;
+	if( strcmp( name, "map_item_stick" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_STICK;
+	if( strcmp( name, "map_item_acce" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_ACCE;
+	if( strcmp( name, "map_item_accessory" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_ACCE;
+	if( strcmp( name, "map_item_inst" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_INST;
+	if( strcmp( name, "map_item_instrument" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_INST;
+	if( strcmp( name, "map_item_light" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_LIGHT;
+	if( strcmp( name, "map_item_spike" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_SPIKE;
+	if( strcmp( name, "map_item_food" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_FOOD;
+	if( strcmp( name, "map_item_chest" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_CHEST;
+	if( strcmp( name, "map_item_rare_GOODS" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_RARE_GOODS;
+	if( strcmp( name, "map_item_rare_goods" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_RARE_GOODS;
+	if( strcmp( name, "map_item_bone" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_BONE;
+	if( strcmp( name, "map_item_coin" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_COIN;
+	if( strcmp( name, "map_item_junk" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MAP_ITEM_JUNK;
+
+	if( strcmp( name, "mbr_1" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_1;
+	if( strcmp( name, "mbr_2" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_2;
+	if( strcmp( name, "mbr_3" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_3;
+	if( strcmp( name, "mbr_4" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_4;
+	if( strcmp( name, "mbr_5" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_5;
+	if( strcmp( name, "mbr_6" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_6;
+
+	if( strcmp( name, "member_1" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_1;
+	if( strcmp( name, "member_2" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_2;
+	if( strcmp( name, "member_3" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_3;
+	if( strcmp( name, "member_4" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_4;
+	if( strcmp( name, "member_5" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_5;
+	if( strcmp( name, "member_6" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MBR_6;
+
 	if( strcmp( name, "fx_mbr_plus" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_FX_MBR_PLUS;
 	if( strcmp( name, "fx_mbr_minus" ) == 0 )
@@ -1104,18 +1338,20 @@ bool_t	load_game_conf_color_name( char *id, char *name )
 		g_crnt_attr_n = CURS_ATTR_N_FX_MNSTR_CRTCL;
 	if( strcmp( name, "vfx" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_VFX;
-	if( strcmp( name, "mbr_1" ) == 0 )
-		g_crnt_attr_n = CURS_ATTR_N_MBR_1;
-	if( strcmp( name, "mbr_2" ) == 0 )
-		g_crnt_attr_n = CURS_ATTR_N_MBR_2;
-	if( strcmp( name, "mbr_3" ) == 0 )
-		g_crnt_attr_n = CURS_ATTR_N_MBR_3;
-	if( strcmp( name, "mbr_4" ) == 0 )
-		g_crnt_attr_n = CURS_ATTR_N_MBR_4;
-	if( strcmp( name, "mbr_5" ) == 0 )
-		g_crnt_attr_n = CURS_ATTR_N_MBR_5;
-	if( strcmp( name, "mbr_6" ) == 0 )
-		g_crnt_attr_n = CURS_ATTR_N_MBR_6;
+
+	if( strcmp( name, "fx_member_plus" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_FX_MBR_PLUS;
+	if( strcmp( name, "fx_member_minus" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_FX_MBR_MINUS;
+	if( strcmp( name, "fx_member_critical" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_FX_MBR_CRTCL;
+	if( strcmp( name, "fx_monster_plus" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_FX_MNSTR_PLUS;
+	if( strcmp( name, "fx_monster_minus" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_FX_MNSTR_MINUS;
+	if( strcmp( name, "fx_monster_critical" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_FX_MNSTR_CRTCL;
+
 	if( strcmp( name, "heat" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_HEAT;
 	if( strcmp( name, "cold" ) == 0 )
@@ -1475,7 +1711,7 @@ bool_t	load_game_data_cnf( long n )
 
 	/* СΥå */
 
-	if( !chk_ver_old( &ver,
+	if( chk_ver_new( &ver,
 			GAME_DATA_VER_MJR,
 			GAME_DATA_VER_MNR,
 			GAME_DATA_VER_PAT ) ){
@@ -1514,19 +1750,19 @@ bool_t	load_game_data_cnf( long n )
 
 	/* Сʥå */
 
-	if( chk_ver_old( &ver, 1, 0, 3 ) )
+	if( chk_ver_old( &ver, 1, 0, 4 ) )
 		ver_up_game_data_1_0_4();
 
-	if( chk_ver_old( &ver, 1, 1, 0 ) )
+	if( chk_ver_old( &ver, 1, 1, 1 ) )
 		ver_up_game_data_1_1_1();
 
-	if( chk_ver_old( &ver, 1, 1, 2 ) )
+	if( chk_ver_old( &ver, 1, 1, 3 ) )
 		ver_up_game_data_1_1_3();
 
-	if( chk_ver_old( &ver, 1, 2, 11 ) )
+	if( chk_ver_old( &ver, 1, 2, 12 ) )
 		ver_up_game_data_1_2_12();
 
-	if( chk_ver_old( &ver, 1, 2, 21 ) )
+	if( chk_ver_old( &ver, 1, 2, 22 ) )
 		ver_up_game_data_cnf_1_2_22();
 
 	/* եΥ */
@@ -1934,10 +2170,14 @@ bool_t	save_game_conf_contents( FILE *fp, const ver_t *ver )
 	flg_err |= !save_game_conf_frame_rate( fp, ver );
 	flg_err |= !save_game_conf_screen_size( fp, ver );
 	flg_err |= !save_game_conf_scroll( fp, ver );
+	flg_err |= !save_game_conf_crsr_ptn_n( fp, ver );
 	flg_err |= !save_game_conf_flg( fp, ver );
+	flg_err |= !save_game_conf_audio_buf_siz( fp, ver );
 	flg_err |= !save_game_conf_gnome( fp, ver );
 	flg_err |= !save_game_conf_set_window_position( fp, ver );
 	flg_err |= !save_game_conf_win_pos( fp, ver );
+	flg_err |= !save_game_conf_mouse( fp, ver );
+	flg_err |= !save_game_conf_sound( fp, ver );
 	flg_err |= !save_game_conf_joystick( fp, ver );
 	flg_err |= !save_game_conf_vfx( fp, ver );
 	flg_err |= !save_game_conf_color( fp, ver );
@@ -2066,6 +2306,30 @@ bool_t	save_game_conf_scroll( FILE *fp, const ver_t *ver )
 	return TRUE;
 }
 
+/***************************************************************
+* եγƥ롦ѥֹΥ
+* FILE *fp : ե
+* const ver_t *ver : եΥС
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	save_game_conf_crsr_ptn_n( FILE *fp, const ver_t *ver )
+{
+	if( fp == NULL )
+		return FALSE;
+	if( ver == NULL )
+		return FALSE;
+
+	fprintf( fp, "\n" );
+	fprintf( fp, "# number of cursor pattern\n" );
+	fprintf( fp, "cursor_number_main = %ld\n",
+			(long)get_main_crsr_ptn_n() );
+	fprintf( fp, "cursor_number_sub = %ld\n",
+			(long)get_sub_crsr_ptn_n() );
+
+	return TRUE;
+}
+
 /***************************************************************
 * եγƥե饰Υ
 * FILE *fp : ե
@@ -2106,9 +2370,31 @@ bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver )
 			(long)chk_msg_mul_line() );
 
 	fprintf( fp, "\n" );
-	fprintf( fp, "# move cursor to default\n" );
-	fprintf( fp, "move_cursor_to_default = %ld\n",
-			(long)get_flg_move_crsr_dflt() );
+	fprintf( fp, "# draw hint of character on the status bar\n" );
+	fprintf( fp, "status_bar_hint_character = %ld\n",
+			(long)get_flg_stat_bar_hint_chr() );
+
+	fprintf( fp, "\n" );
+	fprintf( fp, "# draw hint of object on the status bar\n" );
+	fprintf( fp, "status_bar_hint_object = %ld\n",
+			(long)get_flg_stat_bar_hint_obj() );
+
+	return TRUE;
+}
+
+/***************************************************************
+* եβХåեΥ
+* FILE *fp : ե
+* const ver_t *ver : եΥС
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	save_game_conf_audio_buf_siz( FILE *fp, const ver_t *ver )
+{
+	fprintf( fp, "\n" );
+	fprintf( fp, "# audio buffer size\n" );
+	fprintf( fp, "audio_buffer_size = %ld\n",
+			(long)g_audio_buf_siz );
 
 	return TRUE;
 }
@@ -2187,6 +2473,64 @@ bool_t	save_game_conf_win_pos( FILE *fp, const ver_t *ver )
 	return TRUE;
 }
 
+/***************************************************************
+* եΥޥΥ
+* FILE *fp : ե
+* const ver_t *ver : եΥС
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	save_game_conf_mouse( FILE *fp, const ver_t *ver )
+{
+	if( fp == NULL )
+		return FALSE;
+	if( ver == NULL )
+		return FALSE;
+
+	fprintf( fp, "\n" );
+	fprintf( fp, "# mouse\n" );
+	fprintf( fp, "\n" );
+
+	fprintf( fp, "# move cursor to default\n" );
+	fprintf( fp, "move_cursor_to_default = %ld\n",
+			(long)get_flg_move_crsr_dflt() );
+	fprintf( fp, "\n" );
+
+	fprintf( fp, "# double click wait for CUI mouse\n" );
+	fprintf( fp, "double_click_wait = %ld\n",
+			(long)get_cui_mouse_double_click_msec() );
+	fprintf( fp, "\n" );
+
+	return TRUE;
+}
+
+/***************************************************************
+* ե BGM/SE Υ
+* FILE *fp : ե
+* const ver_t *ver : եΥС
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	save_game_conf_sound( FILE *fp, const ver_t *ver )
+{
+	if( fp == NULL )
+		return FALSE;
+	if( ver == NULL )
+		return FALSE;
+
+	fprintf( fp, "\n" );
+	fprintf( fp, "# music and sound\n" );
+	fprintf( fp, "\n" );
+
+	fprintf( fp, "music_volume = %ld\n",
+			(long)get_music_volume_rate() );
+	fprintf( fp, "sound_volume = %ld\n",
+			(long)get_sound_volume_rate() );
+	fprintf( fp, "\n" );
+
+	return TRUE;
+}
+
 /***************************************************************
 * եΥ祤ƥåΥ
 * FILE *fp : ե
@@ -2293,52 +2637,100 @@ bool_t	save_game_conf_color( FILE *fp, const ver_t *ver )
 
 	save_game_conf_color_sub( fp, "normal",
 			CURS_ATTR_N_NORMAL );
-	save_game_conf_color_sub( fp, "rev",
+	save_game_conf_color_sub( fp, "reverse",
 			CURS_ATTR_N_REV );
-	save_game_conf_color_sub( fp, "err",
+	save_game_conf_color_sub( fp, "error",
 			CURS_ATTR_N_ERR );
+
 	save_game_conf_color_sub( fp, "menu_normal",
 			CURS_ATTR_N_MENU_NORMAL );
-	save_game_conf_color_sub( fp, "menu_dis",
+	save_game_conf_color_sub( fp, "menu_disable",
 			CURS_ATTR_N_MENU_DIS );
-	save_game_conf_color_sub( fp, "menu_sel",
+	save_game_conf_color_sub( fp, "menu_select",
 			CURS_ATTR_N_MENU_SEL );
-	save_game_conf_color_sub( fp, "map_item",
-			CURS_ATTR_N_MAP_ITEM );
-	save_game_conf_color_sub( fp, "map_square",
+
+	save_game_conf_color_sub( fp, "map_cursor",
+			CURS_ATTR_N_MAP_CRSR );
+	save_game_conf_color_sub( fp, "map_anchor",
 			CURS_ATTR_N_MAP_SQUARE );
-	save_game_conf_color_sub( fp, "map_mnstr",
+	save_game_conf_color_sub( fp, "map_wall",
+			CURS_ATTR_N_MAP_WALL );
+	save_game_conf_color_sub( fp, "map_floor",
+			CURS_ATTR_N_MAP_FLOOR );
+	save_game_conf_color_sub( fp, "map_door",
+			CURS_ATTR_N_MAP_DOOR );
+	save_game_conf_color_sub( fp, "map_stairs",
+			CURS_ATTR_N_MAP_STAIRS );
+	save_game_conf_color_sub( fp, "map_trap",
+			CURS_ATTR_N_MAP_TRAP );
+	save_game_conf_color_sub( fp, "map_monster",
 			CURS_ATTR_N_MAP_MNSTR );
 	save_game_conf_color_sub( fp, "map_npc",
 			CURS_ATTR_N_MAP_NPC );
-	save_game_conf_color_sub( fp, "map_crsr",
-			CURS_ATTR_N_MAP_CRSR );
-	save_game_conf_color_sub( fp, "fx_mbr_plus",
+	save_game_conf_color_sub( fp, "map_pet",
+			CURS_ATTR_N_MAP_PET );
+
+	save_game_conf_color_sub( fp, "map_item",
+			CURS_ATTR_N_MAP_ITEM );
+	save_game_conf_color_sub( fp, "map_item_weapon",
+			CURS_ATTR_N_MAP_ITEM_WPN );
+	save_game_conf_color_sub( fp, "map_item_armor",
+			CURS_ATTR_N_MAP_ITEM_ARMOR );
+	save_game_conf_color_sub( fp, "map_item_potion",
+			CURS_ATTR_N_MAP_ITEM_POTION );
+	save_game_conf_color_sub( fp, "map_item_scroll",
+			CURS_ATTR_N_MAP_ITEM_SCROLL );
+	save_game_conf_color_sub( fp, "map_item_stick",
+			CURS_ATTR_N_MAP_ITEM_STICK );
+	save_game_conf_color_sub( fp, "map_item_accessory",
+			CURS_ATTR_N_MAP_ITEM_ACCE );
+	save_game_conf_color_sub( fp, "map_item_instrument",
+			CURS_ATTR_N_MAP_ITEM_INST );
+	save_game_conf_color_sub( fp, "map_item_light",
+			CURS_ATTR_N_MAP_ITEM_LIGHT );
+	save_game_conf_color_sub( fp, "map_item_spike",
+			CURS_ATTR_N_MAP_ITEM_SPIKE );
+	save_game_conf_color_sub( fp, "map_item_food",
+			CURS_ATTR_N_MAP_ITEM_FOOD );
+	save_game_conf_color_sub( fp, "map_item_chest",
+			CURS_ATTR_N_MAP_ITEM_CHEST );
+	save_game_conf_color_sub( fp, "map_item_rare_goods",
+			CURS_ATTR_N_MAP_ITEM_RARE_GOODS );
+	save_game_conf_color_sub( fp, "map_item_bone",
+			CURS_ATTR_N_MAP_ITEM_BONE );
+	save_game_conf_color_sub( fp, "map_item_coin",
+			CURS_ATTR_N_MAP_ITEM_COIN );
+	save_game_conf_color_sub( fp, "map_item_junk",
+			CURS_ATTR_N_MAP_ITEM_JUNK );
+
+	save_game_conf_color_sub( fp, "member_1",
+			CURS_ATTR_N_MBR_1 );
+	save_game_conf_color_sub( fp, "member_2",
+			CURS_ATTR_N_MBR_2 );
+	save_game_conf_color_sub( fp, "member_3",
+			CURS_ATTR_N_MBR_3 );
+	save_game_conf_color_sub( fp, "member_4",
+			CURS_ATTR_N_MBR_4 );
+	save_game_conf_color_sub( fp, "member_5",
+			CURS_ATTR_N_MBR_5 );
+	save_game_conf_color_sub( fp, "member_6",
+			CURS_ATTR_N_MBR_6 );
+
+	save_game_conf_color_sub( fp, "fx_member_plus",
 			CURS_ATTR_N_FX_MBR_PLUS );
-	save_game_conf_color_sub( fp, "fx_mbr_minus",
+	save_game_conf_color_sub( fp, "fx_member_minus",
 			CURS_ATTR_N_FX_MBR_MINUS );
-	save_game_conf_color_sub( fp, "fx_mbr_crtcl",
+	save_game_conf_color_sub( fp, "fx_member_critical",
 			CURS_ATTR_N_FX_MBR_CRTCL );
-	save_game_conf_color_sub( fp, "fx_mnstr_plus",
+	save_game_conf_color_sub( fp, "fx_monster_plus",
 			CURS_ATTR_N_FX_MNSTR_PLUS );
-	save_game_conf_color_sub( fp, "fx_mnstr_minus",
+	save_game_conf_color_sub( fp, "fx_monster_minus",
 			CURS_ATTR_N_FX_MNSTR_MINUS );
-	save_game_conf_color_sub( fp, "fx_mnstr_crtcl",
+	save_game_conf_color_sub( fp, "fx_monster_critical",
 			CURS_ATTR_N_FX_MNSTR_CRTCL );
 	save_game_conf_color_sub( fp, "vfx",
 			CURS_ATTR_N_VFX );
-	save_game_conf_color_sub( fp, "mbr_1",
-			CURS_ATTR_N_MBR_1 );
-	save_game_conf_color_sub( fp, "mbr_2",
-			CURS_ATTR_N_MBR_2 );
-	save_game_conf_color_sub( fp, "mbr_3",
-			CURS_ATTR_N_MBR_3 );
-	save_game_conf_color_sub( fp, "mbr_4",
-			CURS_ATTR_N_MBR_4 );
-	save_game_conf_color_sub( fp, "mbr_5",
-			CURS_ATTR_N_MBR_5 );
-	save_game_conf_color_sub( fp, "mbr_6",
-			CURS_ATTR_N_MBR_6 );
+
 	save_game_conf_color_sub( fp, "heat",
 			CURS_ATTR_N_HEAT );
 	save_game_conf_color_sub( fp, "cold",
