@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-replay.c,v 1.3 2009/06/26 16:58:16 bowkenken Exp $
+* $Id: gf-replay.c,v 1.6 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -70,7 +70,7 @@ bool_t	load_game_replay( bool_t flg_txt_data, long n )
 
 	/* СΥå */
 
-	if( !chk_ver_old( &ver,
+	if( chk_ver_new( &ver,
 			GAME_DATA_VER_MJR,
 			GAME_DATA_VER_MNR,
 			GAME_DATA_VER_PAT ) ){
