@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.c,v 1.213 2010/05/16 18:52:56 bowkenken Exp $
+* $Id: gfile.c,v 1.216 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -45,7 +45,7 @@
 
 void	init_game_file( void )
 {
-	char	*home, *s;
+	const char	*home, *s;
 
 	g_rc_lex_num_mode = 0;
 
@@ -123,7 +123,7 @@ void	reset_static_game_file( void )
 * return : ǥ쥯ȥΥեѥ(顼ʤNULL)
 ***************************************************************/
 
-char	*init_dir_game( char *home, char *dir, bool_t flg_GPL )
+char	*init_dir_game( const char *home, const char *dir, bool_t flg_GPL )
 {
 	char	*name;
 
@@ -149,9 +149,13 @@ char	*init_dir_game( char *home, char *dir, bool_t flg_GPL )
 * return : ۡࡦǥ쥯ȥ
 ***************************************************************/
 
-char	*get_home_dir( void )
+const char	*get_home_dir( void )
 {
-	char	*home;
+	const char	*home;
+
+	home = call_get_home_dir();
+	if( home != NULL )
+		return home;
 
 	home = getenv( STR_ENV_HOME );
 
@@ -2878,6 +2882,21 @@ long	trans_coin_kind_to_idx( coin_kind_t k )
 	return 0;
 }
 
+/***************************************************************
+* ǥåʸμؤѴơ֥ǿ֤
+* return : ǿ
+***************************************************************/
+
+long	get_spell_kind_trans_tab_max_n( void )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_spell_trans_tab );
+	max_idx /= sizeof( g_spell_trans_tab[0] );
+
+	return max_idx;
+}
+
 /***************************************************************
 * ǥåʸμѴ
 * long idx : ǥå
@@ -3088,6 +3107,63 @@ long	trans_request_kind_to_idx( request_kind_t k )
 	return 0;
 }
 
+/***************************************************************
+* ǥåɲμؤѴơ֥ǿ֤
+* return : ǿ
+***************************************************************/
+
+long	get_stay_inn_kind_trans_tab_max_n( void )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_stay_inn_kind_trans_tab );
+	max_idx /= sizeof( g_stay_inn_kind_trans_tab[0] );
+
+	return max_idx;
+}
+
+/***************************************************************
+* ǥåɲμѴ
+* long idx : ǥå
+* return : ɲμ
+***************************************************************/
+
+stay_inn_kind_t	trans_idx_to_stay_inn_kind( long idx )
+{
+	long	max_idx;
+
+	max_idx = sizeof( g_stay_inn_kind_trans_tab )
+			/ sizeof( g_stay_inn_kind_trans_tab[0] );
+
+	if( idx < 0 )
+		return STAY_INN_KIND_MAX_N;
+	if( idx >= max_idx )
+		return STAY_INN_KIND_MAX_N;
+
+	return( g_stay_inn_kind_trans_tab[idx] );
+}
+
+/***************************************************************
+* ɲμफ饤ǥåѴ
+* request_kind_t k : ɲμ
+* return : ǥå
+***************************************************************/
+
+long	trans_stay_inn_kind_to_idx( request_kind_t k )
+{
+	long	max_idx;
+	long	i;
+
+	max_idx = sizeof( g_stay_inn_kind_trans_tab )
+			/ sizeof( g_stay_inn_kind_trans_tab[0] );
+
+	for( i = 0; i < max_idx; i++ )
+		if( g_stay_inn_kind_trans_tab[i] == k )
+			return i;
+
+	return 0;
+}
+
 /***************************************************************
 * ե򥳥ԡ
 * const char *src : ԡեѥ
@@ -3144,7 +3220,7 @@ bool_t	copy_file( const char *src, const char *dst )
 * return : եѥ
 ***************************************************************/
 
-char	*cat_path( char *path, char *file )
+char	*cat_path( const char *path, const char *file )
 {
 	static char	dst[FILE_NAME_MAX_LEN + 1];
 
@@ -3161,7 +3237,7 @@ char	*cat_path( char *path, char *file )
 * return : ¸ߤ?
 ***************************************************************/
 
-bool_t	chk_exist_file( char *s )
+bool_t	chk_exist_file( const char *s )
 {
 	FILE	*fp;
 
@@ -3181,7 +3257,7 @@ bool_t	chk_exist_file( char *s )
 * return : ¸ߤ?
 ***************************************************************/
 
-bool_t	chk_exist_dir( char *s )
+bool_t	chk_exist_dir( const char *s )
 {
 	FILE	*fp;
 
@@ -3206,7 +3282,7 @@ bool_t	chk_exist_dir( char *s )
 * return : 顼̵ä?
 ***************************************************************/
 
-bool_t	make_dir( char *path )
+bool_t	make_dir( const char *path )
 {
 	char	cur_path[FILE_NAME_MAX_LEN + 1];
 	char	*p;
@@ -3239,7 +3315,7 @@ bool_t	make_dir( char *path )
 * return : 顼̵ä?
 ***************************************************************/
 
-bool_t	make_dir_node( char *path )
+bool_t	make_dir_node( const char *path )
 {
 	if( path == NULL )
 		return FALSE;
