@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.h,v 1.24 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: gfile.h,v 1.26 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_H
@@ -122,7 +122,11 @@
 #define	SAVE_N_BUG_REPO	999
 
 /* ե̾Ĺ */
-#define	FILE_NAME_MAX_LEN	127
+#ifdef	D_IPHONE
+# define	FILE_NAME_MAX_LEN	255
+#else	/* D_IPHONE */
+# define	FILE_NAME_MAX_LEN	127
+#endif	/* D_IPHONE */
 
 /* ϤΥȡκʸ */
 #define	TOKEN_MAX_LEN	4096
