@@ -52,6 +52,9 @@ void	ena_term_dos( void );
 void	dis_term_dos( void );
 void	set_key_wait_dos( void );
 void	clr_key_wait_dos( void );
+bool_t	check_memory( check_memory_t mem, const char *msg );
+void	check_memory_all( void );
+void	check_memory_gmain_c( void );
 
 #ifdef __cplusplus
 }
