@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu-tab.h,v 1.15 2010/05/13 17:31:58 bowkenken Exp $
+* $Id: imenu-tab.h,v 1.17 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	IMENU_TAB_H
@@ -495,7 +495,7 @@ menu_t	ls_menu_mbr_flg[MBR_ITEM_MAX_N + 4];
 
 menu_t	ls_menu_lang_ls[LANG_KIND_MAX_N * 2];
 
-menu_t	ls_menu_color[2 + 1 + CURS_ATTR_MAX_N + 10 + 1];
+menu_t	ls_menu_color[2 + 1 + CURS_ATTR_N_MAX_N + 10 + 1];
 menu_t	ls_menu_color_sel[] = {
 	{
 		"/color",
