@@ -234,6 +234,8 @@ bool_t	chk_bar_limit_inst( chr_t *chr );
 bool_t	chk_equip_kind( item_t *item, equip_kind_t kind );
 bool_t	take_off_item( mbr_t *mbr, equip_kind_t kind );
 bool_t	take_off_item_sub( mbr_t *mbr, equip_kind_t kind );
+bool_t	chk_take_off_curse( mbr_t *mbr, equip_kind_t kind );
+bool_t	put_item_in_chest_quick( mbr_t *mbr, item_t *item );
 bool_t	break_item_fragile( item_t *item, bool_t flg_mbr );
 void	break_item_contents( item_t *chest, mbr_t *mbr );
 bool_t	break_item( item_t *item, bool_t flg_mbr );
@@ -340,6 +342,9 @@ void	free_item( item_t *p );
 void	ins_ls_item( item_t *ls, item_t *p );
 bool_t	ins_sort_item( item_t *ls, item_t *item );
 bool_t	chk_ins_sort_item( item_t *ls, item_t *item, long max_n );
+bool_t	chk_have_chest( mbr_t *mbr );
+bool_t	ins_sort_item_chest( item_t *ls, item_t *item );
+bool_t	chk_ins_sort_item_chest( item_t *ls, item_t *item );
 bool_t	chk_give_mbr_chest( mbr_t *mbr, item_t *item );
 bool_t	chk_item_is_equip( item_t *p );
 bool_t	chk_dagger( const wpn_tab_t *arw_tab );
