@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: item.h,v 1.102 2009/09/03 11:26:34 bowkenken Exp $
+* $Id: item.h,v 1.106 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	ITEM_H
@@ -81,6 +81,13 @@
 /* ƥबƤΨ */
 #define	CURSE_ITEM_RATE	((rate_t)30)
 
+/* ȢäƤ륢ƥκǾ */
+#define	CHEST_HOLD_MIN_N	4
+/* ȢäƤ륢ƥκ */
+#define	CHEST_HOLD_MAX_N	8
+/* ٤Ȣκ */
+#define	CAN_CARRY_CHEST_MAX_N	1
+
 /* ƥδ */
 
 #define	FACE_MJR_WEAPON	')'
@@ -546,6 +553,7 @@ typedef enum {
 	SCROLL_KIND_POW_UP_ARMOR_CRTCL,
 	SCROLL_KIND_POW_UP_ARMOR_AC,
 	SCROLL_KIND_PROTECT_ARMOR,
+	SCROLL_KIND_BOOMERANG,
 	SCROLL_KIND_REMOVE_CURSE,
 	SCROLL_KIND_RECALL,
 	SCROLL_KIND_TYPHOON,
