@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: last-boss.h,v 1.12 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: last-boss.h,v 1.14 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	LAST_BOSS_H
@@ -136,16 +136,16 @@ typedef struct {
 ***************************************************************/
 
 #define	XX_ACID_IMAGE_MAX_N	5
-#define	XX_ACID_HOMING_FIX_POINT	(1.0)
+#define	XX_ACID_HOMING_FIX_POINT	256
 
 typedef struct {
 	long	homing_idx;
-	double	homing_vx[MBR_MAX_N];
-	double	homing_vy[MBR_MAX_N];
-	double	homing_mx[MBR_MAX_N];
-	double	homing_my[MBR_MAX_N];
-	double	homing_x[MBR_MAX_N][XX_ACID_IMAGE_MAX_N];
-	double	homing_y[MBR_MAX_N][XX_ACID_IMAGE_MAX_N];
+	long	homing_vx[MBR_MAX_N];
+	long	homing_vy[MBR_MAX_N];
+	long	homing_mx[MBR_MAX_N];
+	long	homing_my[MBR_MAX_N];
+	long	homing_x[MBR_MAX_N][XX_ACID_IMAGE_MAX_N];
+	long	homing_y[MBR_MAX_N][XX_ACID_IMAGE_MAX_N];
 } xx_acid_t;
 
 /***************************************************************
