@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.h,v 1.53 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: menu.h,v 1.55 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MENU_H
@@ -87,6 +87,10 @@
 /* ܿ */
 #define	MENU_MAX_N	(MENU_MAX_N_PER_PAGE * MENU_MAX_PAGE)
 
+/**** ե饰 ****/
+
+typedef unsigned long	flg_menu_t;
+
 /* ̵ */
 #define	FLG_MENU_DIS	(1 << 0)
 
@@ -103,6 +107,8 @@
 	(FLG_MENU_DIS | FLG_MENU_HIDDEN \
 	| FLG_MENU_CHK_ON | FLG_MENU_CHK_OFF)
 
+/****  ****/
+
 /* ˥塼ѥκʸ */
 #define	MENU_PATH_MAX_LEN	80
 
@@ -177,7 +183,7 @@ typedef struct menu_t {
 	void	*arg;
 
 	/* ե饰 */
-	unsigned long	flg;
+	flg_menu_t	flg;
 } menu_t;
 
 typedef struct {
