@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: misc.c,v 1.48 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: misc.c,v 1.50 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -369,12 +369,12 @@ rate_t	modified_rate( rate_t rate, long n )
 }
 
 /***************************************************************
-* С󤬻Ͱ?
+* С󤬻ͤŤ?
 * const ver_t *ver : С
 * long mjr : ᥸㡼С
 * long mnr : ޥʡС
 * long pat : ѥå٥
-* return : Ͱ?
+* return : ͤŤ?
 ***************************************************************/
 
 bool_t	chk_ver_old( const ver_t *ver, long mjr, long mnr, long pat )
@@ -397,6 +397,70 @@ bool_t	chk_ver_old( const ver_t *ver, long mjr, long mnr, long pat )
 	if( ver->pat < pat )
 		return TRUE;
 
+	return FALSE;
+}
+
+/***************************************************************
+* С󤬻ͤ꿷?
+* const ver_t *ver : С
+* long mjr : ᥸㡼С
+* long mnr : ޥʡС
+* long pat : ѥå٥
+* return : ͤ꿷?
+***************************************************************/
+
+bool_t	chk_ver_new( const ver_t *ver, long mjr, long mnr, long pat )
+{
+	if( ver == NULL )
+		return FALSE;
+
+	if( ver->mjr > mjr )
+		return TRUE;
+	if( ver->mjr < mjr )
+		return FALSE;
+
+	if( ver->mnr > mnr )
+		return TRUE;
+	if( ver->mnr < mnr )
+		return FALSE;
+
+	if( ver->pat > pat )
+		return TRUE;
+	if( ver->pat < pat )
+		return FALSE;
+
+	return FALSE;
+}
+
+/***************************************************************
+* С󤬻ͤƱ꿷?
+* const ver_t *ver : С
+* long mjr : ᥸㡼С
+* long mnr : ޥʡС
+* long pat : ѥå٥
+* return : ͤƱ꿷?
+***************************************************************/
+
+bool_t	chk_ver_new_match( const ver_t *ver, long mjr, long mnr, long pat )
+{
+	if( ver == NULL )
+		return FALSE;
+
+	if( ver->mjr > mjr )
+		return TRUE;
+	if( ver->mjr < mjr )
+		return FALSE;
+
+	if( ver->mnr > mnr )
+		return TRUE;
+	if( ver->mnr < mnr )
+		return FALSE;
+
+	if( ver->pat > pat )
+		return TRUE;
+	if( ver->pat < pat )
+		return FALSE;
+
 	return TRUE;
 }
 
