@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.57 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.69 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -40,6 +40,11 @@
 
 /**/
 
+/* С֥˥塼ͭ/̵ե饰 */
+#define	FLG_ENA_MISC_POSITION	0
+
+/**/
+
 menu_t	ls_menu_main_race[] = {
 	{
 		"/main race",
@@ -402,7 +407,7 @@ menu_t	ls_menu_main[] = {
 		'I',
 		"",
 		N_MSG_MENU_INFO, "",
-		NULL, NULL,
+		cb_menu_info, NULL,
 		FLG_NULL,
 	},
 	{
@@ -424,7 +429,25 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/info/list message",
+		"/misc/info/switch status mode",
+		"<Item>",
+		'Z',
+		"Z",
+		N_MSG_MENU_SWITCH_STAT_MODE, "",
+		cb_menu_switch_stat_mode, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/info/message",
+		"<Branch>",
+		'S',
+		"",
+		N_MSG_MENU_MSG, "",
+		cb_menu_msg, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/info/message/list",
 		"<OpenWinItem>",
 		'L',
 		"g",
@@ -432,6 +455,24 @@ menu_t	ls_menu_main[] = {
 		cb_menu_ls_msg, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/info/message/prev",
+		"<Item>",
+		'P',
+		"",
+		N_MSG_MENU_SCROLL_MSG_PREV, "",
+		cb_menu_scroll_msg, (void *)-1,
+		FLG_NULL,
+	},
+	{
+		"/misc/info/message/next",
+		"<Item>",
+		'N',
+		"",
+		N_MSG_MENU_SCROLL_MSG_NEXT, "",
+		cb_menu_scroll_msg, (void *)+1,
+		FLG_NULL,
+	},
 	{
 		"/misc/info/list key item",
 		"<Item>",
@@ -498,7 +539,7 @@ menu_t	ls_menu_main[] = {
 	{
 		"/misc/stairs/last boss",
 		"<Item>",
-		'D',
+		'X',
 		"",
 		N_MSG_MENU_STAIRS_LAST_BOSS, "",
 		cb_menu_stairs_last_boss, NULL,
@@ -558,6 +599,17 @@ menu_t	ls_menu_main[] = {
 		cb_menu_formation, NULL,
 		FLG_NULL,
 	},
+#if	FLG_ENA_MISC_POSITION
+	{
+		"/misc/position",
+		"<Branch>",
+		'P',
+		"",
+		N_MSG_MENU_POSITION, "",
+		cb_menu_position, NULL,
+		FLG_NULL,
+	},
+#endif
 	{
 		"/misc/cursor",
 		"<Branch>",
@@ -637,7 +689,7 @@ menu_t	ls_menu_main[] = {
 		'R',
 		"",
 		N_MSG_MENU_RESET_FILE, "",
-		NULL, NULL,
+		cb_menu_set_dflt_cnf, NULL,
 		FLG_NULL,
 	},
 	{
@@ -650,7 +702,16 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/reset file/town ptn",
+		"/misc/config/reset file/cursor pattern",
+		"<Item>",
+		'S',
+		"",
+		N_MSG_MENU_RESET_FILE_CRSR_PTN, "",
+		cb_menu_reset_file_crsr_ptn, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/reset file/town pattern",
 		"<Item>",
 		'T',
 		"",
@@ -701,7 +762,7 @@ menu_t	ls_menu_main[] = {
 		'V',
 		"",
 		N_MSG_MENU_SCREEN, "",
-		NULL, NULL,
+		cb_menu_set_dflt_cnf, NULL,
 		FLG_NULL,
 	},
 	{
@@ -776,6 +837,33 @@ menu_t	ls_menu_main[] = {
 		cb_menu_mul_msg_line, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/screen/window/status bar",
+		"<Branch>",
+		'B',
+		"",
+		N_MSG_MENU_STAT_BAR, "",
+		cb_menu_stat_bar_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/window/status bar/hint chr",
+		"<CheckItem>",
+		'C',
+		"",
+		N_MSG_MENU_STAT_BAR_HINT_CHR, "",
+		cb_menu_stat_bar_hint_chr, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/window/status bar/hint obj",
+		"<CheckItem>",
+		'O',
+		"",
+		N_MSG_MENU_STAT_BAR_HINT_OBJ, "",
+		cb_menu_stat_bar_hint_obj, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/config/screen/window/size",
 		"<Branch>",
@@ -955,7 +1043,25 @@ menu_t	ls_menu_main[] = {
 		'V',
 		"",
 		N_MSG_MENU_CRSR_PTN, "",
-		cb_menu_crsr_ptn, NULL,
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/cursor pattern/main",
+		"<Branch>",
+		'M',
+		"",
+		N_MSG_MENU_CRSR_PTN_MAIN, "",
+		cb_menu_crsr_ptn, (void *)TRUE,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/cursor pattern/sub",
+		"<Branch>",
+		'S',
+		"",
+		N_MSG_MENU_CRSR_PTN_SUB, "",
+		cb_menu_crsr_ptn, (void *)FALSE,
 		FLG_NULL,
 	},
 	{
@@ -1127,61 +1233,7 @@ menu_t	ls_menu_main[] = {
 		'G',
 		"",
 		N_MSG_MENU_GUI, "",
-		cb_menu_gui, NULL,
-		FLG_NULL,
-	},
-	{
-		"/misc/config/gui/move cursor to default",
-		"<CheckItem>",
-		'C',
-		"",
-		N_MSG_MENU_MOVE_CRSR_DFLT, "",
-		cb_menu_move_crsr_dflt, NULL,
-		FLG_NULL,
-	},
-	{
-		"/misc/config/gui/sound",
-		"<Branch>",
-		'S',
-		"",
-		N_MSG_MENU_SOUND, "",
-		cb_menu_sound, NULL,
-		FLG_NULL,
-	},
-	{
-		"/misc/config/gui/sound/sound volume",
-		"<OpenWinItem>",
-		'S',
-		"",
-		N_MSG_MENU_SOUND_VOLUME, "",
-		cb_menu_sound_volume, NULL,
-		FLG_NULL,
-	},
-	{
-		"/misc/config/gui/sound/music volume",
-		"<OpenWinItem>",
-		'M',
-		"",
-		N_MSG_MENU_MUSIC_VOLUME, "",
-		cb_menu_music_volume, NULL,
-		FLG_NULL,
-	},
-	{
-		"/misc/config/gui/sound/mute",
-		"<CheckItem>",
-		'U',
-		"",
-		N_MSG_MENU_MUTE_SOUND, "",
-		cb_menu_mute_sound, NULL,
-		FLG_NULL,
-	},
-	{
-		"/misc/config/gui/sound/replay music",
-		"<Item>",
-		'R',
-		"p",
-		N_MSG_MENU_REPLAY_MUSIC, "",
-		cb_menu_replay_music, NULL,
+		cb_menu_set_dflt_cnf, NULL,
 		FLG_NULL,
 	},
 	{
@@ -1190,9 +1242,90 @@ menu_t	ls_menu_main[] = {
 		'M',
 		"",
 		N_MSG_MENU_MOUSE, "",
+		cb_menu_mouse_init, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/mouse/move cursor to default",
+		"<CheckItem>",
+		'C',
+		"",
+		N_MSG_MENU_MOVE_CRSR_DFLT, "",
+		cb_menu_mouse_move_crsr_dflt, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/mouse/double click",
+		"<OpenWinItem>",
+		'W',
+		"",
+		N_MSG_MENU_MOUSE_DOUBLE_CLICK, "",
+		cb_menu_mouse_double_click, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/mouse/assign",
+		"<Branch>",
+		'B',
+		"",
+		N_MSG_MENU_MOUSE_ASSIGN, "",
 		cb_menu_mouse, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/gui/audio",
+		"<Branch>",
+		'A',
+		"",
+		N_MSG_MENU_AUDIO, "",
+		cb_menu_audio, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/audio/sound volume",
+		"<OpenWinItem>",
+		'S',
+		"",
+		N_MSG_MENU_SOUND_VOLUME, "",
+		cb_menu_sound_volume, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/audio/music volume",
+		"<OpenWinItem>",
+		'M',
+		"",
+		N_MSG_MENU_MUSIC_VOLUME, "",
+		cb_menu_music_volume, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/audio/mute",
+		"<CheckItem>",
+		'U',
+		"",
+		N_MSG_MENU_MUTE_AUDIO, "",
+		cb_menu_mute_audio, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/audio/replay music",
+		"<Item>",
+		'R',
+		"p",
+		N_MSG_MENU_REPLAY_MUSIC, "",
+		cb_menu_replay_music, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/gui/audio/set buffer size",
+		"<OpenWinItem>",
+		'B',
+		"",
+		N_MSG_MENU_SET_AUDIO_BUF_SIZ, "",
+		cb_menu_set_audio_buf_siz, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/config/gui/joystick",
 		"<Branch>",
@@ -1250,7 +1383,7 @@ menu_t	ls_menu_main[] = {
 	{
 		"/misc/config/gui/joystick/macro",
 		"<Branch>",
-		'M',
+		'B',
 		"",
 		N_MSG_MENU_JOYSTICK_MACRO, "",
 		cb_menu_joystick_macro_init, NULL,
@@ -1283,7 +1416,7 @@ menu_t	ls_menu_main[] = {
 		'R',
 		"",
 		N_MSG_MENU_REPLAY, "",
-		NULL, NULL,
+		cb_menu_set_dflt_system, NULL,
 		FLG_NULL,
 	},
 	{
@@ -1393,7 +1526,7 @@ menu_t	ls_menu_main[] = {
 		'T',
 		"",
 		N_MSG_MENU_WIZARD_ADD_TURN, "",
-		NULL, NULL,
+		cb_menu_set_dflt_wizard, NULL,
 		FLG_NULL,
 	},
 	{
@@ -1456,7 +1589,7 @@ menu_t	ls_menu_main[] = {
 		'C',
 		"",
 		N_MSG_MENU_WIZARD_SCENE, "",
-		NULL, NULL,
+		cb_menu_set_dflt_wizard, NULL,
 		FLG_NULL,
 	},
 	{
