@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.60 2010/05/15 19:34:47 bowkenken Exp $
+* $Id: mmenu.c,v 1.65 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -40,9 +40,9 @@
 
 /**/
 
-static pos_t	g_crsr, g_pre_crsr;
+static pos_t	g_main_crsr, g_pre_main_crsr;
 static pos_t	g_sub_crsr, g_pre_sub_crsr;
-check_memory_def( check_memory_mmenu_c_g_crsr )
+check_memory_def( check_memory_mmenu_c_g_main_crsr )
 
 static menu_t	*g_menu_dflt_main;
 check_memory_def( check_memory_mmenu_c_g_menu_dflt_main )
@@ -120,7 +120,8 @@ void	init_main_menu( void )
 {
 	set_flg_no_save( FALSE );
 	next_pos_square( +1 );
-	g_pre_crsr = g_crsr;
+	g_pre_main_crsr = g_main_crsr;
+	g_pre_sub_crsr = g_sub_crsr;
 	g_menu_dflt_main = NULL;
 }
 
@@ -371,7 +372,7 @@ char	*exec_menu_sel_abl( mbr_t *mbr, abl_kind_t *abl )
 
 char	*cb_menu_sel_abl( menu_t **pp, menu_t **dflt )
 {
-	g_sel_abl = (abl_kind_t)(int)((*pp)->arg);
+	g_sel_abl = (abl_kind_t)(long)((*pp)->arg);
 
 	return NULL;
 }
@@ -588,7 +589,7 @@ char	*cb_menu_main_init( menu_t **pp, menu_t **dflt )
 {
 	dun_t	*dun = get_dun();
 
-	g_sel_mbr_n = get_mbr_n( g_crsr.x, g_crsr.y );
+	g_sel_mbr_n = get_mbr_n( g_main_crsr.x, g_main_crsr.y );
 
 	clr_flg_menu( *pp, NULL, FLG_MENU_ALL );
 
@@ -643,7 +644,7 @@ char	*cb_menu_mark( menu_t **pp, menu_t **dflt )
 	trgt_kind_1 = TRGT_KIND_NULL;
 	trgt_kind_2 = TRGT_KIND_NULL;
 
-	pos1 = g_crsr;
+	pos1 = g_main_crsr;
 
 	flg_cont = TRUE;
 	while( flg_cont ){
@@ -652,7 +653,7 @@ char	*cb_menu_mark( menu_t **pp, menu_t **dflt )
 			return str;
 
 		if( trgt_kind_1 == TRGT_KIND_NULL ){
-			if( menu_mark_square( g_crsr ) )
+			if( menu_mark_square( g_main_crsr ) )
 				return NULL;
 			else
 				return STR_MENU_ERR;
@@ -670,16 +671,16 @@ char	*cb_menu_mark( menu_t **pp, menu_t **dflt )
 			/* ΥåȤ˥ư */
 			if( pty->mbr[g_sel_mbr_n]->trgt.kind
 					!= TRGT_KIND_SQUARE ){
-				g_crsr.x = pty->mbr[g_sel_mbr_n]
+				g_main_crsr.x = pty->mbr[g_sel_mbr_n]
 						->trgt.true_x;
-				g_crsr.y = pty->mbr[g_sel_mbr_n]
+				g_main_crsr.y = pty->mbr[g_sel_mbr_n]
 						->trgt.true_y;
 			}
 		}
 		while( 1 ){
 			str = exec_menu_point_crsr();
 			if( str != NULL ){
-				g_crsr = pos1;
+				g_main_crsr = pos1;
 				redraw_all();
 
 				if( strcmp( str, STR_MENU_CANCEL ) == 0 )
@@ -687,7 +688,7 @@ char	*cb_menu_mark( menu_t **pp, menu_t **dflt )
 				if( strcmp( str, STR_MENU_ERR ) == 0 )
 					return str;
 			}
-			pos2 = g_crsr;
+			pos2 = g_main_crsr;
 
 			str = exec_menu_sel_obj( &trgt_kind_2, pos2 );
 			if( str != NULL ){
@@ -774,10 +775,10 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 	long	sq_x, sq_y;
 	dun_t	*dun = get_dun();
 
-	mjr_chr = dun->map.chr.mjr[g_crsr.y][g_crsr.x];
-	flg_chr = dun->map.chr.flg[g_crsr.y][g_crsr.x];
-	mjr_obj = dun->map.obj.mjr[g_crsr.y][g_crsr.x];
-	flg_obj = dun->map.obj.flg[g_crsr.y][g_crsr.x];
+	mjr_chr = dun->map.chr.mjr[g_main_crsr.y][g_main_crsr.x];
+	flg_chr = dun->map.chr.flg[g_main_crsr.y][g_main_crsr.x];
+	mjr_obj = dun->map.obj.mjr[g_main_crsr.y][g_main_crsr.x];
+	flg_obj = dun->map.obj.flg[g_main_crsr.y][g_main_crsr.x];
 
 	clr_flg_menu( *pp, NULL, FLG_MENU_ALL );
 
@@ -797,12 +798,12 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 
 	/* 饹ܥ */
 
-	if( chk_xx_pos( g_crsr.x, g_crsr.y ) )
+	if( chk_xx_pos( g_main_crsr.x, g_main_crsr.y ) )
 		clr_flg_menu( *pp, "monster", FLG_MENU_HIDDEN );
 
 	/* ƥ */
 
-	if( get_item( g_crsr.x, g_crsr.y ) == NULL )
+	if( get_item( g_main_crsr.x, g_main_crsr.y ) == NULL )
 		set_flg_menu( *pp, "item", FLG_MENU_HIDDEN );
 
 	/* ɥ */
@@ -838,9 +839,9 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 	/* 󥫡 */
 
 	get_square_pos( &sq_x, &sq_y, FALSE );
-	if( labs( sq_x - g_crsr.x ) > (SQUARE_WIDTH / 2) )
+	if( labs( sq_x - g_main_crsr.x ) > (SQUARE_WIDTH / 2) )
 		set_flg_menu( *pp, "square", FLG_MENU_HIDDEN );
-	if( labs( sq_y - g_crsr.y ) > (SQUARE_HEIGHT / 2) )
+	if( labs( sq_y - g_main_crsr.y ) > (SQUARE_HEIGHT / 2) )
 		set_flg_menu( *pp, "square", FLG_MENU_HIDDEN );
 
 	/* ޡ */
@@ -1779,7 +1780,7 @@ char	*cb_menu_item_zap( menu_t **pp, menu_t **dflt )
 	if( str != NULL )
 		return str;
 
-	str = exec_menu_sel_obj( &trgt_kind, g_crsr );
+	str = exec_menu_sel_obj( &trgt_kind, g_main_crsr );
 	if( str != NULL )
 		return str;
 
@@ -1789,14 +1790,14 @@ char	*cb_menu_item_zap( menu_t **pp, menu_t **dflt )
 	case TRGT_KIND_MAX_N:
 		return STR_MENU_ERR;
 	case TRGT_KIND_MBR:
-		mbr2 = get_mbr( g_crsr.x, g_crsr.y );
+		mbr2 = get_mbr( g_main_crsr.x, g_main_crsr.y );
 		if( mbr2 == NULL )
 			return STR_MENU_ERR;
 
 		mark_mbr( mbr, mbr2, DIST_FAR );
 		break;
 	case TRGT_KIND_MNSTR:
-		mnstr = get_mnstr( g_crsr.x, g_crsr.y );
+		mnstr = get_mnstr( g_main_crsr.x, g_main_crsr.y );
 		if( mnstr == NULL )
 			return STR_MENU_ERR;
 
@@ -1805,24 +1806,24 @@ char	*cb_menu_item_zap( menu_t **pp, menu_t **dflt )
 	case TRGT_KIND_MNSTR_NULL:
 	case TRGT_KIND_POS:
 		mark_mnstr_null_no_regist(
-				mbr, g_crsr.x, g_crsr.y, DIST_FAR );
+				mbr, g_main_crsr.x, g_main_crsr.y, DIST_FAR );
 		break;
 	case TRGT_KIND_ITEM:
-		item = get_item( g_crsr.x, g_crsr.y );
+		item = get_item( g_main_crsr.x, g_main_crsr.y );
 		if( item == NULL )
 			return STR_MENU_ERR;
 
 		mark_item( mbr, item, DIST_FAR );
 		break;
 	case TRGT_KIND_DOOR:
-		door = get_door( g_crsr.x, g_crsr.y );
+		door = get_door( g_main_crsr.x, g_main_crsr.y );
 		if( door == NULL )
 			return STR_MENU_ERR;
 
 		mark_door( mbr, door, DIST_FAR );
 		break;
 	case TRGT_KIND_TRAP:
-		trap = get_trap( g_crsr.x, g_crsr.y );
+		trap = get_trap( g_main_crsr.x, g_main_crsr.y );
 		if( trap == NULL )
 			return STR_MENU_ERR;
 
@@ -2732,16 +2733,16 @@ void	menu_move_square( void )
 
 	/* ưθ˹碌ƤΥ󥫡θꤹ */
 
-	if( labs( sq->x - g_crsr.x ) > labs( sq->y - g_crsr.y ) ){
-		if( g_crsr.x < sq->x ){
+	if( labs( sq->x - g_main_crsr.x ) > labs( sq->y - g_main_crsr.y ) ){
+		if( g_main_crsr.x < sq->x ){
 			sq->dir = SQUARE_DIR_WEST;
-		} else if( g_crsr.x > sq->x ){
+		} else if( g_main_crsr.x > sq->x ){
 			sq->dir = SQUARE_DIR_EAST;
 		}
 	} else {
-		if( g_crsr.y < sq->y ){
+		if( g_main_crsr.y < sq->y ){
 			sq->dir = SQUARE_DIR_NORTH;
-		} else if( g_crsr.y > sq->y ){
+		} else if( g_main_crsr.y > sq->y ){
 			sq->dir = SQUARE_DIR_SOUTH;
 		}
 	}
@@ -2770,8 +2771,8 @@ void	menu_move_square( void )
 			sq->dir = SQUARE_DIR_NORTH;
 	}
 
-	sq->x = g_crsr.x;
-	sq->y = g_crsr.y;
+	sq->x = g_main_crsr.x;
+	sq->y = g_main_crsr.y;
 	set_square_mbr( sq );
 	reset_mbr_dir();
 
@@ -2791,7 +2792,7 @@ char	*cb_menu_fight( menu_t **pp, menu_t **dflt )
 
 	flg_loop = FALSE;
 	do {
-		pos1 = g_crsr;
+		pos1 = g_main_crsr;
 		c = get_chr_mjr_crsr();
 		if( c != FACE_MJR_MBR ){
 			mbr_t	*mbr;
@@ -2819,7 +2820,7 @@ char	*cb_menu_fight( menu_t **pp, menu_t **dflt )
 				return str;
 		}
 
-		pos2 = g_crsr;
+		pos2 = g_main_crsr;
 		c = get_chr_mjr_crsr();
 
 		if( c == FACE_MJR_MBR ){
@@ -2839,6 +2840,7 @@ char	*cb_menu_fight( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_load_wiz( menu_t **pp, menu_t **dflt )
 {
+	set_menu_dflt_wizard( *pp );
 	menu_load_wiz();
 
 	return STR_MENU_CANCEL;
@@ -2848,6 +2850,7 @@ char	*cb_menu_load_wiz( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_save_wiz( menu_t **pp, menu_t **dflt )
 {
+	set_menu_dflt_wizard( *pp );
 	menu_save_wiz();
 
 	return STR_MENU_CANCEL;
@@ -3456,27 +3459,27 @@ void	set_menu_dflt_main( menu_t *p )
 
 void	update_crsr( void )
 {
-	draw_crsr();
+	draw_main_crsr();
 	draw_sub_crsr();
 
 	/* ơС˥ҥȤɽ */
-	call_gui_map_print_stat_bar_hint();
+	draw_stat_bar();
 
 	reset_crsr();
 }
 
 /**/
 
-pos_t	*get_crsr( void )
+pos_t	*get_main_crsr( void )
 {
-	return &g_crsr;
+	return &g_main_crsr;
 }
 
 /**/
 
-pos_t	*get_pre_crsr( void )
+pos_t	*get_pre_main_crsr( void )
 {
-	return &g_pre_crsr;
+	return &g_pre_main_crsr;
 }
 
 /**/
@@ -3513,8 +3516,8 @@ void	set_sel_mbr_n( long n )
 
 void	check_memory_mmenu_c( void )
 {
-	check_memory( check_memory_mmenu_c_g_crsr,
-			"mmenu.c: g_crsr" );
+	check_memory( check_memory_mmenu_c_g_main_crsr,
+			"mmenu.c: g_main_crsr" );
 	check_memory( check_memory_mmenu_c_g_menu_dflt_main,
 			"mmenu.c: g_menu_dflt_main" );
 	check_memory( check_memory_mmenu_c_g_sub_sel_mbr,
