@@ -25,6 +25,7 @@ bool_t	make_mnstr_special( mnstr_t *p, long dun_lev );
 mnstr_t	*make_npc_rand( long x, long y, long dun_lev );
 void	move_phase_all_mnstr( void );
 void	act_phase_all_mnstr( void );
+void	dismissal_phase_all_mnstr( void );
 bool_t	chk_can_act_mnstr( mnstr_t *p );
 void	set_act_mnstr( mnstr_t *p );
 mbr_t	*mnstr_mark_mbr_std( mnstr_t *p );
@@ -92,6 +93,7 @@ mnstr_t	*get_mnstr_hp_mp_min_max(
 mnstr_t	*get_mnstr_randm( long x, long y );
 bool_t	already_mark_mnstr( mnstr_t *mnstr, mbr_t *mbr );
 mnstr_t	*get_mnstr_randm2( long x, long y );
+chr_t	*get_mnstr_friend( mnstr_t *p, long x, long y );
 mnstr_kind_t	get_mnstr_kind_from_face( char mjr, char mnr );
 mnstr_t	*get_last_boss( last_boss_kind_t kind );
 mnstr_t	*get_mnstr_used( void );
