@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.230 2009/09/03 01:57:50 bowkenken Exp $
+* $Id: mnstr.c,v 1.234 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -300,6 +300,7 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->id2 = 0;
 	mnstr->mbr_n = MBR_N_NOT_JOIN;
 	mnstr->ls_mbr_n = 0;
+	mnstr->position_kind = POSITION_KIND_FORWARD;
 	mnstr->face.mjr = FACE_MJR_NULL;
 	mnstr->face.mnr = FACE_MNR_NULL;
 	mnstr->face.mjr_org = FACE_MJR_NULL;
@@ -2580,6 +2581,9 @@ mnstr_t	*get_mnstr( long x, long y )
 	if( !clip_pos( x, y ) )
 		return NULL;
 
+	if( dun->map.chr.mjr[y][x] == FACE_MJR_NULL )
+		return NULL;
+
 	p = dun->map.chr_p[y][x];
 	if( (p != NULL) && (p->kind == CHR_KIND_MNSTR) )
 		return p;
