@@ -26,9 +26,11 @@ void	get_square_mbr_abs_pos( long mbr_n, long *x, long *y );
 void	get_square_mbr_map_pos( long mbr_n, long *x, long *y );
 void	appear_party_auto( void );
 void	appear_party( void );
-bool_t	appear_party_randm( void );
-bool_t	appear_party_srch( void );
-void	appear_party_force( void );
+bool_t	appear_party_sub_randm( void );
+bool_t	appear_party_sub_srch( void );
+void	appear_party_sub_force( void );
+bool_t	appear_party_short( long bx, long by );
+bool_t	appear_party_sub_area( long bx, long by );
 void	appear_party_last_boss( void );
 void	appear_party_map_event( char mnr );
 long	get_party_dun_max_lev( void );
