@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.249 2010/05/29 14:37:00 bowkenken Exp $
+* $Id: party.c,v 1.255 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -251,7 +251,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_FIGHTER, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_090.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-01.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
@@ -261,7 +261,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], ")(==DRANK======>", 'D', race,
 			MALE, CLASS_N_FIGHTER, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_194.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-02.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
@@ -271,7 +271,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_042.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-03.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_HALFBACK;
 
@@ -281,7 +281,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_214r.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-04.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
@@ -291,7 +291,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_212r.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-05.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_BACK;
 
@@ -301,7 +301,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_018.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-06.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_BACK;
 
@@ -311,7 +311,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_216r.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-07.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
@@ -321,7 +321,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_242.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-08.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
@@ -483,7 +483,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_NINJA, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_090.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-01.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
@@ -493,7 +493,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_DWARF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], ")(==DRANK======>", 'D', race,
 			MALE, CLASS_N_FIGHTER, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_194.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-02.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
@@ -503,7 +503,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_042.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-03.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_HALFBACK;
 
@@ -513,7 +513,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_214r.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-04.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
@@ -523,7 +523,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_212r.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-05.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_BACK;
 
@@ -533,7 +533,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_018.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-06.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_BACK;
 
@@ -543,7 +543,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_216r.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-07.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
@@ -553,7 +553,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_RACE_NAME_NEKOMIMI, RACE_NAME_MAX_BYTE );
 	new_mbr( ls_mbr[i], "----EYE-------|===", 'Y', race,
 			FEMALE, CLASS_N_SUMMONER, i );
-	str_nz_cpy( ls_mbr[i]->graph_name, "mon_242.bmp",
+	str_nz_cpy( ls_mbr[i]->graph_name, "default-08.bmp",
 			FILE_NAME_MAX_LEN );
 	ls_mbr[i]->position_kind = POSITION_KIND_FORWARD;
 
@@ -2373,6 +2373,9 @@ void	mbr_peep_door( mbr_t *mbr, long dr_n )
 void	clr_party_act( void )
 {
 	party.act.kind = ACT_KIND_NULL;
+	str_nz_cpy( party.act.msg, "", ACT_MSG_MAX_BYTE );
+
+	draw_misc_stat();
 }
 
 /**/
@@ -2412,31 +2415,24 @@ void	not_join_mbr( long ls_mbr_n, long mbr_n )
 
 void	collect_gold( mbr_t *mbr )
 {
-	bool_t	flg_force;
-	gold_t	gold, res_price;
+	gold_t	gold;
 	long	i;
 
 	if( mbr == NULL )
 		return;
 
-	/* Ѥ GOLD ϵݽʤ */
+	/* ڥåȤ NPC ϵ */
 
-	res_price = get_price_temple_resurrection( mbr );
-	flg_force = FALSE;
-	if( chk_flg( mbr->stat, FLG_STAT_DEAD )
-			&& (get_chr_gold( mbr ) < res_price)
-			&& (mbr->fx_data.friend_turn > 0) ){
-		flg_force = TRUE;
+	if( !is_mbr( mbr ) ){
+		print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD, mbr->name );
+		return;
 	}
 
 	/* GOLD Τ */
 
 	if( mbr->fx_data.friend_turn > 0 ){
-		if( !flg_force ){
-			print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
-					mbr->name );
-			return;
-		}
+		print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD, mbr->name );
+		return;
 	}
 
 	gold = 0;
@@ -2447,11 +2443,9 @@ void	collect_gold( mbr_t *mbr )
 		/* GOLD Τ */
 
 		if( party.mbr[i]->fx_data.friend_turn > 0 ){
-			if( !flg_force ){
-				print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
-						party.mbr[i]->name );
-				continue;
-			}
+			print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
+					party.mbr[i]->name );
+			continue;
 		}
 
 		gold += get_chr_gold( party.mbr[i] );
@@ -2467,20 +2461,9 @@ void	collect_gold( mbr_t *mbr )
 
 void	divide_gold( void )
 {
-	bool_t	flg_force;
 	gold_t	sum, gold;
 	long	i, n, mod_n;
 
-	/* Ѥ GOLD ϵݽʤ */
-
-	flg_force = FALSE;
-	for( i = 0; i < MBR_MAX_N; i++ ){
-		if( chk_flg( party.mbr[i]->stat, FLG_STAT_DEAD ) ){
-			flg_force = TRUE;
-			break;
-		}
-	}
-
 	mod_n = 0;
 	n = 0;
 	sum = 0;
@@ -2491,11 +2474,9 @@ void	divide_gold( void )
 		/* GOLD Τ */
 
 		if( party.mbr[i]->fx_data.friend_turn > 0 ){
-			if( !flg_force ){
-				print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
-						party.mbr[i]->name );
-				continue;
-			}
+			print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
+					party.mbr[i]->name );
+			continue;
 		}
 
 		sum += get_chr_gold( party.mbr[i] );
@@ -2512,8 +2493,7 @@ void	divide_gold( void )
 		if( chk_flg( party.mbr[i]->stat, FLG_STAT_NOT_EXIST ) )
 			continue;
 		if( party.mbr[i]->fx_data.friend_turn > 0 )
-			if( !flg_force )
-				continue;
+			continue;
 
 		add_chr_gold( party.mbr[i], gold );
 		sum -= gold;
@@ -2541,52 +2521,48 @@ void	give_gold( mbr_t *mbr_from, mbr_t *mbr_to, gold_t gold )
 	/* Ѥ GOLD ϵݽʤ */
 
 	res_price = get_price_temple_resurrection( mbr_to );
-	if( chk_flg( mbr_to->stat, FLG_STAT_DEAD )
-			&& (get_chr_gold( mbr_to ) < res_price)
-			&& (mbr_to->fx_data.friend_turn > 0) ){
+	if( (get_chr_gold( mbr_to ) + gold <= res_price)
+			&& chk_flg( mbr_to->stat, FLG_STAT_DEAD ) ){
 		flg_force = TRUE;
 	}
 
 	/* 夯餤 GOLD ϵݤʤ */
 
 	inn_price = get_price_inn( FALSE );
-	do {
-		if( mbr_from->fx_data.friend_turn > 0 )
-			break;
-		if( mbr_to->fx_data.friend_turn <= 0 )
-			break;
-		if( get_chr_gold( mbr_to ) + gold > inn_price )
-			break;
-
+	if( get_chr_gold( mbr_to ) + gold <= inn_price )
 		flg_force = TRUE;
-		break;
-	} while( 0 );
 
 	/* 礬ɤå */
 
 	do {
-		if( flg_force )
-			break;
-		if( mbr_from->fx_data.friend_turn <= 0 )
-			if( mbr_to->fx_data.friend_turn <= 0 )
+		if( !flg_force ){
+			if( mbr_from->fx_data.friend_turn > 0 )
 				break;
+			if( mbr_to->fx_data.friend_turn > 0 )
+				break;
+			if( is_pet( mbr_from ) )
+				break;
+			if( !is_mbr( mbr_to ) )
+				break;
+		}
 
-		/* GOLD Τ */
+		max = GOLD_MAX - get_chr_gold( mbr_to );
+		if( gold > max )
+			gold = max;
 
-		print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD,
+		add_chr_gold( mbr_from, -gold );
+		add_chr_gold( mbr_to, +gold );
+
+		print_msg( FLG_NULL, MSG_GIVE_GOLD,
+				mbr_from->name, fmt_gold( gold ),
 				mbr_to->name );
+
 		return;
 	} while( 0 );
 
-	max = GOLD_MAX - get_chr_gold( mbr_to );
-	if( gold > max )
-		gold = max;
+	/* GOLD Τ */
 
-	add_chr_gold( mbr_from, -gold );
-	add_chr_gold( mbr_to, +gold );
-
-	print_msg( FLG_NULL, MSG_GIVE_GOLD,
-			mbr_from->name, fmt_gold( gold ), mbr_to->name );
+	print_msg( FLG_NULL, MSG_NOT_FRIEND_GOLD, mbr_to->name );
 }
 
 /**/
@@ -3571,34 +3547,54 @@ flg_party_t	set_flg_party( flg_party_t flg )
 
 /**/
 
-long	next_mbr( long mbr_n, long add )
+long	next_mbr( long n, long add )
 {
+	pet_t	**pet;
+	long	pet_n;
 	long	i;
 
-	for( i = 0; i < MBR_MAX_N; i++ ){
-		mbr_n += add + MBR_MAX_N;
-		mbr_n %= MBR_MAX_N;
-		if( !chk_flg( party.mbr[mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
-			break;
+	if( add == 0 )
+		return n;
+
+	pet = get_party_pet();
+
+	for( i = 0; i < MBR_MAX_N + PET_MAX_N; i++ ){
+		n += add;
+		n += MBR_MAX_N + PET_MAX_N;
+		n %= MBR_MAX_N + PET_MAX_N;
+
+		if( n < MBR_MAX_N ){
+			if( !chk_flg( party.mbr[n]->stat,
+					FLG_STAT_NOT_EXIST ) ){
+				break;
+			}
+		} else {
+			pet_n = n - MBR_MAX_N;
+			if( (pet[pet_n] != NULL)
+					&& !chk_flg( pet[pet_n]->stat,
+					FLG_STAT_NOT_EXIST ) ){
+				break;
+			}
+		}
 	}
 
-	return mbr_n;
+	return n;
 }
 
 /**/
 
-long	next_ls_mbr( long ls_mbr_n, long add )
+long	next_ls_mbr( long ls_n, long add )
 {
 	long	i;
 
 	for( i = 0; i < LS_MBR_MAX_N; i++ ){
-		ls_mbr_n += add + LS_MBR_MAX_N;
-		ls_mbr_n %= LS_MBR_MAX_N;
-		if( !chk_flg( ls_mbr[ls_mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
+		ls_n += add + LS_MBR_MAX_N;
+		ls_n %= LS_MBR_MAX_N;
+		if( !chk_flg( ls_mbr[ls_n]->stat, FLG_STAT_NOT_EXIST ) )
 			break;
 	}
 
-	return ls_mbr_n;
+	return ls_n;
 }
 
 /**/
