@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.70 2009/07/23 12:52:01 bowkenken Exp $
+* $Id: pet.c,v 1.75 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -450,6 +450,36 @@ void	chk_trap_all_pet( void )
 	}
 }
 
+/***************************************************************
+* ꥹȤμΥڥåֹ֤
+* long n : ڥåȤΥꥹֹ
+* long add : ꥹֹοʹ
+* return : ڥåȤΥꥹֹ
+***************************************************************/
+
+long	next_ls_pet_n( long n, long add )
+{
+	long	next_n;
+	long	i;
+
+	if( add == 0 )
+		return n;
+
+	next_n = n;
+	for( i = 0; i < LS_PET_MAX_N; i++ ){
+		next_n = (next_n + add + LS_PET_MAX_N) % LS_PET_MAX_N;
+
+		if( ls_pet[next_n] == NULL )
+			continue;
+		if( chk_flg_or( ls_pet[next_n]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+
+		return next_n;
+	}
+
+	return n;
+}
+
 /***************************************************************
 * ѡƥΤĤƤڥåȤΥꥹȤ֤
 * return : ڥåȤΥꥹ
@@ -483,6 +513,12 @@ pet_t	*get_pet( long x, long y )
 	pet_t	*p;
 	long	i;
 
+	if( !clip_pos( x, y ) )
+		return NULL;
+
+	if( dun->map.chr.mjr[y][x] == FACE_MJR_NULL )
+		return NULL;
+
 	p = dun->map.chr_p[y][x];
 	if( (p != NULL) && is_pet( p ) )
 		return p;
@@ -513,6 +549,42 @@ pet_t	*get_pet( long x, long y )
 	return NULL;
 }
 
+/***************************************************************
+* ڥåȤΥڥåֹ֤
+* pet_t *pet : ڥå
+* return : ڥåֹ
+***************************************************************/
+
+long	get_pet_n( pet_t *pet )
+{
+	long	i;
+
+	for( i = 0; i < PET_MAX_N; i++ ){
+		if( pet == party_pet[i] )
+			return i;
+	}
+
+	return -1;
+}
+
+/***************************************************************
+* ڥåȤΥڥåȡꥹֹ֤
+* pet_t *pet : ڥå
+* return : ڥåȡꥹֹ
+***************************************************************/
+
+long	get_pet_ls_n( pet_t *pet )
+{
+	long	i;
+
+	for( i = 0; i < LS_PET_MAX_N; i++ ){
+		if( pet == ls_pet[i] )
+			return i;
+	}
+
+	return -1;
+}
+
 /***************************************************************
 * ΰ˴ط NPC (ڥå)򸡺
 * request_t *req : 
