@@ -26,6 +26,7 @@ bool_t	set_replay_char_slot(
 );
 bool_t	ready_replay( replay_slot_t sn, bool_t flg_break );
 bool_t	get_draw_replay( char *buf, long *idx, long *len );
+void	get_draw_replay_gui( char *buf, long len );
 void	chk_replay_key( long c );
 long	get_replay_key( void );
 long	get_replay_next_key( replay_t **pp, long *idx );
@@ -38,6 +39,7 @@ long	get_replay_save_n( void );
 replay_t	*get_replay_head( long n );
 replay_t	*alloc_replay( void );
 void	free_replay( replay_t *p );
+void	check_memory_replay_c( void );
 
 #ifdef __cplusplus
 }
