@@ -105,12 +105,16 @@ bool_t	chk_finish_request_revenge( request_t *req, chr_t *chr );
 bool_t	chk_finish_request_wanted_criminal( request_t *req );
 void	close_all_request( chr_kind_t chr_kind );
 bool_t	close_request( request_t *req, chr_kind_t chr_kind );
+void	give_party_reward_item_randm();
+bool_t	give_party_reward_item( item_t *item );
+bool_t	chk_watch_request_client( request_t *req );
 void	not_join_all_client( request_t *req, bool_t flg_success );
 void	not_join_client( request_t *req, pet_t *npc, bool_t flg_success );
 void	put_request_all_obj( void );
 void	put_request_rare_goods( chr_t *chr );
 void	put_request_item( void );
 void	put_request_mnstr( void );
+bool_t	is_client( chr_t *chr );
 char	*cb_menu_request_mbr( menu_t **pp, menu_t **dflt );
 char	*cb_menu_request_bar( menu_t **pp, menu_t **dflt );
 char	*set_menu_request(
@@ -129,6 +133,7 @@ char	*cv_idx_to_mnstr_name( request_t *req );
 char	*cv_idx_to_rescue_trgt_name( request_t *req );
 char	*cv_idx_to_client_family_name( request_t *req );
 char	*cv_idx_to_client_mate_name( request_t *req );
+void	check_memory_request_c( void );
 
 #ifdef __cplusplus
 }
