@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-tab.h,v 1.22 2009/09/04 11:35:11 bowkenken Exp $
+* $Id: spell-tab.h,v 1.26 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_TAB_H
@@ -123,6 +123,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/MAG/short_teleport_party",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SHORT_TELEPORT_PARTY, "",
+		cb_menu_spell, (void *)SPELL_KIND_SHORT_TELEPORT_PARTY,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/MAG/teleport_party",
 		"<Branch>",
@@ -1232,6 +1242,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/SUM/summon_random",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_RANDOM, "",
+		cb_menu_spell, (void *)SPELL_KIND_SUMMON_RANDOM,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/SUM/create_undead",
 		"<Branch>",
