@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.218 2010/05/29 14:37:00 bowkenken Exp $
+* $Id: spell.c,v 1.222 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -324,7 +324,7 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 
 	set_menu_dflt_main( *pp );
 
-	crsr = get_crsr();
+	crsr = get_main_crsr();
 	g_sel_mbr = get_mbr( crsr->x, crsr->y );
 	if( g_sel_mbr == NULL )
 		flg_sel_mbr = TRUE;
@@ -853,7 +853,7 @@ char	*menu_spell_trgt( mbr_t *mbr )
 
 	/* ΥåȤ˥ư */
 
-	crsr = get_crsr();
+	crsr = get_main_crsr();
 	if( crsr == NULL )
 		return STR_MENU_ERR;
 	if( mbr->trgt.kind != TRGT_KIND_SQUARE ){
@@ -1043,7 +1043,9 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 		resi_kind_t	kind;
 		rate_t	d;
 
-		kind = tab->resi;
+		kind = tab->resi_vfx;
+		if( kind >= RESI_KIND_MAX_N )
+			kind = tab->resi;
 
 		if( kind < 0 )
 			return;
@@ -1279,6 +1281,7 @@ void	chr_cast_spell_blast(
 {
 	blast_t	*blast;
 	char	*blast_str;
+	gui_vfx_t	*gui_vfx;
 	long	nx, ny;
 	long	xx, yy;
 	bool_t	flg_actual;
@@ -1317,9 +1320,12 @@ void	chr_cast_spell_blast(
 		}
 	}
 
+	/* GUI */
+	gui_vfx = alloc_gui_vfx_blast( BLAST_KIND_STD );
+
 	blast = get_blast_spell( tab->kind );
 	blast_str = get_spell_vfx_str( tab->kind );
-	draw_blast( kind, x, y, blast, blast_str );
+	draw_blast( kind, x, y, blast, gui_vfx, blast_str );
 	if( clip_draw_pos( x, y ) )
 		wait_clock( ANIM_FRAME_N_BLAST_STD );
 
@@ -1399,6 +1405,8 @@ void	chr_cast_spell_blast(
 				trgt_chr->work.flg |= FLG_WORK_BLAST_END;
 			}
 
+			draw_blast( kind, x, y, blast,
+					gui_vfx, blast_str );
 			draw_map( xx, yy, 1, 1 );
 
 			chr_cast_spell_sub( chr, flg_item, tab, rate,
@@ -1409,10 +1417,15 @@ void	chr_cast_spell_blast(
 	end_sync_vfx_num();
 	clr_all_chr_flg_blast();
 
-	draw_blast( kind, x, y, blast, blast_str );
+	draw_blast( kind, x, y, blast, gui_vfx, blast_str );
 	if( clip_draw_pos( x, y ) )
 		wait_clock( ANIM_FRAME_N_BLAST_STD );
 
+	/* GUI */
+	clr_gui_vfx_all();
+	free_gui_vfx( gui_vfx );
+	call_pcg_dun_redraw( TRUE );
+
 	xx = x - (blast->xr / 2);
 	yy = y - blast->yr;
 	nx = (blast->xl + str_len_draw( blast_str )) / 2;
