@@ -27,6 +27,8 @@ char	*menu_town_mbr_data(
 	mbr_data_edit_kind_t edit_kind,
 	bool_t flg_ls_mbr
 );
+char	*cb_menu_pet_shop_data( menu_t **pp, menu_t **dflt );
+char	*menu_town_pet_data( void );
 char	*cb_menu_shop_collect_gold( menu_t **pp, menu_t **dflt );
 char	*cb_menu_shop_divide_gold( menu_t **pp, menu_t **dflt );
 char	*cb_menu_shop_give_gold( menu_t **pp, menu_t **dflt );
