@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.28 2009/07/20 16:35:24 bowkenken Exp $
+* $Id: tmenu-tab.h,v 1.33 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TMENU_TAB_H
@@ -217,6 +217,16 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/magic guild/MAG/short_teleport_party",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SHORT_TELEPORT_PARTY, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_SHORT_TELEPORT_PARTY,
+		FLG_NULL,
+	},
+
 	{
 		"/magic guild/MAG/teleport_party",
 		"<Branch>",
@@ -276,27 +286,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_DISARM_TRAP,
 		FLG_NULL,
 	},
-
-	{
-		"/magic guild/MAG/dispel_magic",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_DISPEL_MAGIC, "",
-		cb_menu_magic_guild, (void *)SPELL_KIND_DISPEL_MAGIC,
-		FLG_NULL,
-	},
-
-	{
-		"/magic guild/MAG/mirror_image",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_MIRROR_IMAGE, "",
-		cb_menu_magic_guild, (void *)SPELL_KIND_MIRROR_IMAGE,
-		FLG_NULL,
-	},
-
+#if	0
 	{
 		"/magic guild/MAG/animate_objects",
 		"<Branch>",
@@ -306,7 +296,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_ANIMATE_OBJECTS,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/MAG/shelter",
 		"<Branch>",
@@ -386,7 +376,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_SEARCHING,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/MAG/analyze_dweomer",
 		"<Branch>",
@@ -396,7 +386,18 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_ANALYZE_DWEOMER,
 		FLG_NULL,
 	},
-
+#endif
+#if	0
+	{
+		"/magic guild/MAG/detect_magic",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_DETECT_MAGIC, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_DETECT_MAGIC,
+		FLG_NULL,
+	},
+#endif
 	{
 		"/magic guild/MAG/detect_item",
 		"<Branch>",
@@ -427,16 +428,6 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/magic guild/MAG/detect_magic",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_DETECT_MAGIC, "",
-		cb_menu_magic_guild, (void *)SPELL_KIND_DETECT_MAGIC,
-		FLG_NULL,
-	},
-
 	{
 		"/magic guild/MAG/detect_monster",
 		"<Branch>",
@@ -496,7 +487,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_FLY,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/MAG/feather_fall",
 		"<Branch>",
@@ -506,7 +497,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_FEATHER_FALL,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/MAG/vanish",
 		"<Branch>",
@@ -536,7 +527,28 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_PASSWALL,
 		FLG_NULL,
 	},
-
+#if	0
+	{
+		"/magic guild/MAG/dispel_magic",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_DISPEL_MAGIC, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_DISPEL_MAGIC,
+		FLG_NULL,
+	},
+#endif
+#if	0
+	{
+		"/magic guild/MAG/mirror_image",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_MIRROR_IMAGE, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_MIRROR_IMAGE,
+		FLG_NULL,
+	},
+#endif
 	{
 		"/magic guild/MAG/no_learn change status",
 		"<Item>",
@@ -576,7 +588,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_POLYMORPH_OTHER,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/MAG/polymorph_self",
 		"<Branch>",
@@ -586,7 +598,8 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_POLYMORPH_SELF,
 		FLG_NULL,
 	},
-
+#endif
+#if	0
 	{
 		"/magic guild/MAG/stealth",
 		"<Branch>",
@@ -596,7 +609,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_STEALTH,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/MAG/no_learn change special",
 		"<Item>",
@@ -757,16 +770,6 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/magic guild/SOR/mage_armor",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_MAGE_ARMOR, "",
-		cb_menu_magic_guild, (void *)SPELL_KIND_MAGE_ARMOR,
-		FLG_NULL,
-	},
-
 	{
 		"/magic guild/SOR/magic_shield",
 		"<Branch>",
@@ -777,6 +780,16 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/magic guild/SOR/mage_armor",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_MAGE_ARMOR, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_MAGE_ARMOR,
+		FLG_NULL,
+	},
+#if	0
 	{
 		"/magic guild/SOR/stoneskin",
 		"<Branch>",
@@ -786,7 +799,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_STONESKIN,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/SOR/iron_body",
 		"<Branch>",
@@ -796,7 +809,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_IRON_BODY,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/SOR/spell_resistance",
 		"<Branch>",
@@ -806,7 +819,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_SPELL_RESISTANCE,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/SOR/counter_magic",
 		"<Branch>",
@@ -1236,7 +1249,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_SLOW,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/ENC/hunger",
 		"<Branch>",
@@ -1246,7 +1259,8 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_HUNGER,
 		FLG_NULL,
 	},
-
+#endif
+#if	0
 	{
 		"/magic guild/ENC/cancellation",
 		"<Branch>",
@@ -1256,7 +1270,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_CANCELLATION,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/ENC/no_learn weaken misc",
 		"<Item>",
@@ -1356,7 +1370,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_SUMMON_BONE,
 		FLG_NULL,
 	},
-
+#if	0
 	{
 		"/magic guild/SUM/summon_random",
 		"<Branch>",
@@ -1366,7 +1380,8 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_SUMMON_RANDOM,
 		FLG_NULL,
 	},
-
+#endif
+#if	0
 	{
 		"/magic guild/SUM/create_undead",
 		"<Branch>",
@@ -1376,7 +1391,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_CREATE_UNDEAD,
 		FLG_NULL,
 	},
-
+#endif
 	{
 		"/magic guild/SUM/dismissal",
 		"<Branch>",
@@ -1930,6 +1945,15 @@ menu_t	ls_menu_pet_shop[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
+	{
+		"/pet shop/data",
+		"<OpenWinItem>",
+		'D',
+		"",
+		N_MSG_MENU_PET_SHOP_DATA, "",
+		cb_menu_pet_shop_data, NULL,
+		FLG_NULL,
+	},
 	{
 		"/pet shop/buy",
 		"<Branch>",
