@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.159 2010/05/29 14:37:00 bowkenken Exp $
+* $Id: tmenu.c,v 1.167 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -292,7 +292,7 @@ char	*cb_menu_temple_remove_curse( menu_t **pp, menu_t **dflt )
 	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_TEMPLE );
 
 	if( remove_curse( NULL, g_sel_mbr, 0 ) ){
-		add_chr_gold( chr_pay, -price );
+		paying_gold( chr_pay, price );
 
 		print_msg( FLG_NULL,
 				MSG_MENU_REMOVE_CURSE,
@@ -339,7 +339,7 @@ char	*cb_menu_temple_cure_status( menu_t **pp, menu_t **dflt )
 	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_TEMPLE );
 
 	if( fx_cure_all_stat( g_sel_mbr ) ){
-		add_chr_gold( chr_pay, -price );
+		paying_gold( chr_pay, price );
 
 		print_msg( FLG_NULL,
 				MSG_MENU_CURE_STATUS,
@@ -400,7 +400,7 @@ char	*cb_menu_temple_resurrection( menu_t **pp, menu_t **dflt )
 	fx_resurrection( g_sel_mbr, FALSE );
 
 	/* ֤ʤƤʧ */
-	add_chr_gold( chr_pay, -price );
+	paying_gold( chr_pay, price );
 
 	return "/temple";
 }
@@ -447,7 +447,7 @@ char	*cb_menu_temple_contribution( menu_t **pp, menu_t **dflt )
 
 	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_TEMPLE );
 
-	add_chr_gold( chr_pay, -price );
+	paying_gold( chr_pay, price );
 	print_msg( FLG_NULL, MSG_MENU_CONTRIBUTION,
 			g_sel_mbr->name, fmt_gold( price ) );
 	contribution( g_sel_mbr, price, spell_price );
@@ -675,7 +675,7 @@ char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt )
 		if( !chk_pay( pty->mbr[i], price ) )
 			continue;
 
-		add_chr_gold( pty->mbr[i], -price );
+		paying_gold( pty->mbr[i], price );
 		call_game_sound_play( SOUND_KIND_SHOP_BUY_DRINK, 2 );
 
 		tmp = alloc_item();
@@ -1053,18 +1053,24 @@ char	*menu_town_mbr_data(
 	bool_t flg_ls_mbr
 )
 {
+	mbr_t	**ls_mbr;
 	mbr_t	**mbr;
+	pet_t	**pet;
+	chr_t	*chr;
 	long	n;
 	long	page_n;
 	data_n_t	data_n;
 
-	if( flg_ls_mbr ){
+	if( is_pet( g_sel_mbr ) )
+		n = MBR_MAX_N + get_pet_n( g_sel_mbr );
+	else if( flg_ls_mbr )
 		n = g_sel_ls_mbr->ls_mbr_n;
-		mbr = get_ls_mbr();
-	} else {
+	else
 		n = g_sel_mbr->mbr_n;
-		mbr = get_party()->mbr;
-	}
+
+	ls_mbr = get_ls_mbr();
+	mbr = get_party()->mbr;
+	pet = get_party_pet();
 
 	if( n <= -1 )
 		return STR_MENU_ERR;
@@ -1076,11 +1082,22 @@ char	*menu_town_mbr_data(
 		long	add;
 		long	prev_mbr_n;
 
-		prev_mbr_n = mbr[n]->mbr_n;
-		if( flg_ls_mbr )
+		if( flg_ls_mbr ){
+			prev_mbr_n = ls_mbr[n]->mbr_n;
 			not_join_mbr( n, prev_mbr_n );
+		}
 
-		add = menu_mbr_data( mbr[n], &page_n, &data_n, edit_kind );
+		if( flg_ls_mbr ){
+			chr = ls_mbr[n];
+		} else {
+			if( n < MBR_MAX_N ){
+				chr = mbr[n];
+			} else {
+				chr = pet[n - MBR_MAX_N];
+			}
+		}
+
+		add = menu_mbr_data( chr, &page_n, &data_n, edit_kind );
 
 		if( flg_ls_mbr )
 			join_mbr( n, prev_mbr_n );
@@ -1099,6 +1116,55 @@ char	*menu_town_mbr_data(
 
 /**/
 
+char	*cb_menu_pet_shop_data( menu_t **pp, menu_t **dflt )
+{
+	return menu_town_pet_data();
+}
+
+/**/
+
+char	*menu_town_pet_data( void )
+{
+	pet_t	**ls_pet;
+	chr_t	*chr;
+	long	n;
+	long	add;
+	long	page_n;
+	data_n_t	data_n;
+
+	ls_pet = get_ls_pet();
+
+	n = MBR_MAX_N;
+	add = +1;
+	page_n = 0;
+	data_n = DATA_N_NEXT_PAGE;
+
+	while( 1 ){
+		/* ڥåȡꥹȤƬФ */
+
+		n = next_ls_pet_n( n - MBR_MAX_N, add );
+		if( ls_pet[n] == NULL )
+			break;
+		if( chk_flg( ls_pet[n]->stat, FLG_STAT_NOT_EXIST ) )
+			break;
+		n += MBR_MAX_N;
+
+		/* ǡɽ */
+
+		chr = ls_pet[n - MBR_MAX_N];
+		add = menu_mbr_data( chr, &page_n, &data_n,
+				MBR_DATA_EDIT_KIND_SHOW );
+		if( add == 0 )
+			return STR_MENU_CANCEL;
+	}
+
+	print_msg( FLG_MSG_ERR, MSG_ERR_MENU_PET_SHOP_DATA );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
 char	*cb_menu_shop_collect_gold( menu_t **pp, menu_t **dflt )
 {
 	collect_gold( g_sel_mbr );
@@ -1156,7 +1222,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 		if( deal_n <= 0 )
 			return STR_MENU_CANCEL;
 
-		add_chr_gold( g_sel_mbr, -(price * deal_n / n) );
+		paying_gold( g_sel_mbr, price * deal_n / n );
 		call_game_sound_play( SOUND_KIND_SHOP_BUY, 1 );
 
 	} else if( g_deal_kind == DEAL_KIND_SALE_ITEM ){
@@ -1164,7 +1230,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 		if( deal_n <= 0 )
 			return STR_MENU_CANCEL;
 
-		add_chr_gold( g_sel_mbr, +(price * deal_n / n) );
+		paid_gold( g_sel_mbr, price * deal_n / n );
 		call_game_sound_play( SOUND_KIND_SHOP_SALE, 1 );
 
 	} else if( g_deal_kind == DEAL_KIND_SALE_EQUIP ){
@@ -1172,7 +1238,7 @@ char	*cb_menu_shop( menu_t **pp, menu_t **dflt )
 		if( deal_n <= 0 )
 			return STR_MENU_CANCEL;
 
-		add_chr_gold( g_sel_mbr, +(price * deal_n / n) );
+		paid_gold( g_sel_mbr, price * deal_n / n );
 		call_game_sound_play( SOUND_KIND_SHOP_SALE, 1 );
 	}
 
@@ -2173,6 +2239,7 @@ void	menu_bar_arrange_1( mbr_t *mbr, long d )
 	arrange_auto_mark_mbr_1( trgt_ls_mbr_n, d );
 	arrange_item_1( trgt_ls_mbr_n, d );
 	arrange_equip_1( trgt_ls_mbr_n, d );
+	arrange_playing_report_1( trgt_ls_mbr_n, d );
 
 	/**/
 
@@ -2205,6 +2272,7 @@ void	menu_bar_arrange( mbr_t *mbr, long d )
 	arrange_auto_mark_mbr( trgt_ls_mbr_n, d );
 	arrange_item( trgt_ls_mbr_n, d );
 	arrange_equip( trgt_ls_mbr_n, d );
+	arrange_playing_report( trgt_ls_mbr_n, d );
 
 	tmp_mbr = mbr;
 	if( d <= -1 ){
@@ -2653,8 +2721,10 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 		if( n < EDIT_CLASS_NULL + 1 )
 			n = (edit_class_t)(EDIT_CLASS_MAX_N - 1);
 
-		draw_edit_class( org, work, prev_n, FALSE, flg_sel_add );
-		draw_edit_class( org, work, n, TRUE, flg_sel_add );
+		draw_edit_class( org, work, prev_n, FALSE, flg_sel_add,
+				FALSE );
+		draw_edit_class( org, work, n, TRUE, flg_sel_add,
+				FALSE );
 		prev_n = n;
 
 		call_gui_class_edit_draw( work );
@@ -2718,7 +2788,8 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 						flg_sel_add );
 			} else if( n == EDIT_CLASS_NAME ){
 				draw_edit_class( org, work, n,
-						FALSE, flg_sel_add );
+						FALSE, flg_sel_add,
+						FALSE );
 				gets_class_name( work->name );
 			} else {
 				if( flg_sel_add ){
@@ -2731,7 +2802,8 @@ long	exec_edit_class( class_t *org, bool_t flg_new )
 
 				draw_edit_class( org, work,
 						EDIT_CLASS_TOTAL,
-						FALSE, flg_sel_add );
+						FALSE, flg_sel_add,
+						FALSE );
 			}
 		}
 	}
@@ -2768,8 +2840,8 @@ long	exec_edit_skill( class_t *org, bool_t flg_new )
 		if( *pn < EDIT_SKILL_NULL + 1 )
 			*pn = (edit_skill_t)(EDIT_SKILL_MAX_N - 1);
 
-		draw_edit_skill( org, work, prev_n, FALSE );
-		draw_edit_skill( org, work, *pn, TRUE );
+		draw_edit_skill( org, work, prev_n, FALSE, FALSE );
+		draw_edit_skill( org, work, *pn, TRUE, FALSE );
 		prev_n = *pn;
 
 		call_gui_skill_edit_draw( work );
@@ -2827,7 +2899,8 @@ long	exec_edit_skill( class_t *org, bool_t flg_new )
 				}
 				draw_edit_skill_all( org, work, *pn );
 			} else if( *pn == EDIT_SKILL_CLASS_NAME ){
-				draw_edit_skill( org, work, *pn, FALSE );
+				draw_edit_skill( org, work, *pn,
+						FALSE, FALSE );
 				gets_class_name( work->name );
 			} else if( (EDIT_SKILL_A_00 <= *pn)
 					&& (*pn <= EDIT_SKILL_A_09) ){
@@ -3334,7 +3407,7 @@ char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt )
 			continue;
 		}
 
-		add_chr_gold( pty->mbr[mbr_n], -price );
+		paying_gold( pty->mbr[mbr_n], price );
 	}
 
 	call_game_music_play( MUSIC_KIND_EFFECT, ME_KIND_INN );
@@ -3561,7 +3634,7 @@ char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt )
 		return STR_MENU_CANCEL;
 	}
 
-	add_chr_gold( g_sel_mbr, -get_price_spell( kind ) );
+	paying_gold( g_sel_mbr, get_price_spell( kind ) );
 	call_game_sound_play( SOUND_KIND_SHOP_BUY, 1 );
 	set_chr_learned_spell( g_sel_mbr, kind, TRUE );
 
@@ -4237,7 +4310,7 @@ char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt )
 	join_pet( pet );
 	print_msg( FLG_NULL, MSG_MENU_PET_SHOP_BUY_SUCCESS, pet->name );
 
-	add_chr_gold( g_sel_mbr, (gold_t)(-price) );
+	paying_gold( g_sel_mbr, price );
 	call_game_sound_play( SOUND_KIND_SHOP_BUY, 1 );
 
 	return "/pet shop";
@@ -4540,7 +4613,7 @@ char	*cb_menu_auto_sale_exec( menu_t **pp, menu_t **dflt )
 		if( price <= 0 )
 			continue;
 
-		add_chr_gold( g_sel_mbr, +price );
+		paid_gold( g_sel_mbr, +price );
 		sale_sum += sale_n;
 	}
 
