@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town-tab.h,v 1.11 2008/02/04 04:37:44 bowkenken Exp $
+* $Id: town-tab.h,v 1.22 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TOWN_TAB_H
@@ -145,12 +145,12 @@ typedef struct {
 } art_ls_bar_t;
 
 art_ls_bar_t	art_ls_bar[] = {
-	{ ITEM_KIND_FOOD, 256, FOOD_KIND_POTAGE,
-		POTION_KIND_NULL },
-	{ ITEM_KIND_POTION, 256, FOOD_KIND_NULL,
-		POTION_KIND_MILK },
 	{ ITEM_KIND_POTION, 256, FOOD_KIND_NULL,
 		POTION_KIND_ALE },
+	{ ITEM_KIND_POTION, 256, FOOD_KIND_NULL,
+		POTION_KIND_MILK },
+	{ ITEM_KIND_FOOD, 256, FOOD_KIND_SOUP_OF_TURNIP,
+		POTION_KIND_NULL },
 	{ ITEM_KIND_NULL, 0, FOOD_KIND_NULL,
 		POTION_KIND_NULL },
 };
@@ -457,6 +457,26 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
 	},
+
+	{ ITEM_KIND_POTION, 12,
+		POTION_KIND_POISON,
+		SCROLL_KIND_NULL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
+	{ ITEM_KIND_POTION, 12,
+		POTION_KIND_BLIND,
+		SCROLL_KIND_NULL,
+		STICK_KIND_NULL,
+		SPELL_KIND_NULL,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
 /* scroll */
 	{ ITEM_KIND_SCROLL, 12,
 		POTION_KIND_NULL,
@@ -598,6 +618,17 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		NECKLACE_KIND_NULL,
 	},
 
+#if	0
+	{ ITEM_KIND_STICK, 6,
+		POTION_KIND_NULL,
+		SCROLL_KIND_NULL,
+		STICK_KIND_WAND,
+		SPELL_KIND_SHORT_TELEPORT_PARTY,
+		RING_KIND_NULL,
+		AMULET_KIND_NULL,
+		NECKLACE_KIND_NULL,
+	},
+
 	{ ITEM_KIND_STICK, 6,
 		POTION_KIND_NULL,
 		SCROLL_KIND_NULL,
@@ -757,6 +788,7 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
 	},
+#endif
 /* rod */
 	{ ITEM_KIND_STICK, 6,
 		POTION_KIND_NULL,
@@ -767,7 +799,7 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
 	},
-
+#if	0
 	{ ITEM_KIND_STICK, 6,
 		POTION_KIND_NULL,
 		SCROLL_KIND_NULL,
@@ -927,6 +959,7 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
 	},
+#endif
 /* staff */
 	{ ITEM_KIND_STICK, 6,
 		POTION_KIND_NULL,
@@ -937,7 +970,7 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
 	},
-
+#if	0
 	{ ITEM_KIND_STICK, 6,
 		POTION_KIND_NULL,
 		SCROLL_KIND_NULL,
@@ -1217,6 +1250,8 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
 	},
+#endif
+#if	0
 /* ring */
 	{ ITEM_KIND_ACCE, 3,
 		POTION_KIND_NULL,
@@ -1297,6 +1332,8 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_NULL,
 	},
+#endif
+#if	0
 /* amulet */
 	{ ITEM_KIND_ACCE, 3,
 		POTION_KIND_NULL,
@@ -1464,6 +1501,8 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_RESI_STAT_SENSE_INVISIBLE,
 		NECKLACE_KIND_NULL,
 	},
+#endif
+#if	0
 /* necklace */
 	{ ITEM_KIND_ACCE, 3,
 		POTION_KIND_NULL,
@@ -1534,6 +1573,7 @@ art_ls_alchemy_t	art_ls_alchemy[] = {
 		AMULET_KIND_NULL,
 		NECKLACE_KIND_RESI_POIS,
 	},
+#endif
 /* end */
 	{ ITEM_KIND_NULL, 0,
 		POTION_KIND_NULL,
@@ -1578,81 +1618,7 @@ art_ls_music_t	art_ls_music[] = {
 		ANTHOLOGY_KIND_RESI_STAT,
 	},
 /* ڴ */
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_TRUMPET,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_TROMBONE,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_FLUGELHORN,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_CORNET,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_HORN,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_TUBA,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_SOUSAPHONE,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_BUGLE,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_FLUTE,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_CLARINET,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_BASS_CLARINET,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_PICCOLO,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_OBOE,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_BASSOON,
-		ANTHOLOGY_KIND_NULL,
-	},
-
-	{ ITEM_KIND_INST, 6,
-		INST_KIND_SAXOPHONE,
-		ANTHOLOGY_KIND_NULL,
-	},
-
+/* STRINGED -  */
 	{ ITEM_KIND_INST, 6,
 		INST_KIND_VIOLIN,
 		ANTHOLOGY_KIND_NULL,
@@ -1692,7 +1658,82 @@ art_ls_music_t	art_ls_music[] = {
 		INST_KIND_SITAR,
 		ANTHOLOGY_KIND_NULL,
 	},
+/* WOODWIND - ǽͶ */
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_FLUTE,
+		ANTHOLOGY_KIND_NULL,
+	},
 
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_CLARINET,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_BASS_CLARINET,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_PICCOLO,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_OBOE,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_BASSOON,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_SAXOPHONE,
+		ANTHOLOGY_KIND_NULL,
+	},
+/* BRASS - ǽͼ */
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_TRUMPET,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_TROMBONE,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_FLUGELHORN,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_CORNET,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_HORN,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_TUBA,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_SOUSAPHONE,
+		ANTHOLOGY_KIND_NULL,
+	},
+
+	{ ITEM_KIND_INST, 6,
+		INST_KIND_BUGLE,
+		ANTHOLOGY_KIND_NULL,
+	},
+/* PERCUSSION -  */
 	{ ITEM_KIND_INST, 6,
 		INST_KIND_BASS_DRUM,
 		ANTHOLOGY_KIND_NULL,
@@ -1757,7 +1798,7 @@ art_ls_music_t	art_ls_music[] = {
 		INST_KIND_XYLOPHONE,
 		ANTHOLOGY_KIND_NULL,
 	},
-
+/* MISC -  */
 	{ ITEM_KIND_INST, 6,
 		INST_KIND_ACCORDION,
 		ANTHOLOGY_KIND_NULL,
