@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.160 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: town.c,v 1.163 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -2025,18 +2025,23 @@ bool_t	chk_package_item( item_t *item )
 
 /***************************************************************
 * ɲ
-* bool_t flg_short_stay : ٷƤ?
-* bool_t flg_mews : Ͼ뤫?
 ***************************************************************/
 
-void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
+void	stay_inn( stay_inn_kind_t kind )
 {
+	bool_t flg_short_stay, flg_mews;
 	party_t	*pty = get_party();
 	pet_t	**pet = get_party_pet();
 	long	turn;
 	fx_t	*fx;
 	long	i, j;
 
+	/* פ */
+	update_playing_report_staying_inn_party( kind );
+
+	flg_short_stay = (kind == STAY_INN_KIND_SHORT);
+	flg_mews = (kind == STAY_INN_KIND_MEWS);
+
 	if( flg_short_stay ){
 		turn = 12 * TURN_PER_HOUR;
 	} else {
@@ -2058,6 +2063,10 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 			continue;
 		}
 
+		/* פ */
+		update_playing_report_staying_inn_mbr(
+				mbr->ls_mbr_n, kind );
+
 		if( !flg_mews ){
 			/* ǤˤƤʤ HP  */
 			fx = srch_fx( &(mbr->fx), FX_KIND_POISON );
@@ -2089,6 +2098,9 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 
 		/* ̤ۤդ */
 		clean_all_disposal( mbr );
+
+		/* פ */
+		update_playing_report_staying_inn_mbr( mbr->ls_mbr_n, kind );
 	}
 
 	for( i = 0; i < PET_MAX_N; i++ ){
@@ -2124,6 +2136,9 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 		take_meal_fill_chr( pet[i] );
 	}
 
+	/* פ */
+	update_playing_report_staying_inn_party( kind );
+
 	reset_turn( get_turn() + turn );
 	reset_all( FALSE );
 	reset_glow();
@@ -3312,6 +3327,28 @@ void	hear_rumor( shop_n_t shop_n )
 			MSG( rumor_tab[tab_n].n_msg_male ) );
 }
 
+/***************************************************************
+* ʧ
+* chr_t *chr : 饯
+* gold_t price : 
+***************************************************************/
+
+void	paying_gold( chr_t *chr, gold_t price )
+{
+	add_chr_gold( chr, -price );
+}
+
+/***************************************************************
+* λʧ
+* chr_t *chr : 饯
+* gold_t price : 
+***************************************************************/
+
+void	paid_gold( chr_t *chr, gold_t price )
+{
+	add_chr_gold( chr, +price );
+}
+
 /***************************************************************
 * 椫Ĵ٤
 * return : 椫?
