@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.71 2008/10/02 09:21:05 bowkenken Exp $
+* $Id: trap.c,v 1.81 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -79,6 +79,8 @@ static trap_t	trap_free;
 /* µܤγƥΥإå */
 static trap_t	dun_trap_asgn;
 
+check_memory_def( check_memory_trap_c_trap_buf )
+
 /* ǡơ֥κ */
 static long	trap_tab_max_n;
 
@@ -155,9 +157,11 @@ static trap_tab_t	trap_tab[] = {
 		TRUE,
 	},
 };
+check_memory_def( check_memory_trap_c_trap_tab )
 
 /* 櫤ˡȯưΥߡΥ饯 */
 chr_t	g_dmy_chr;
+check_memory_def( check_memory_trap_c_g_dmy_chr )
 
 /***************************************************************
 * 櫤ν
@@ -399,7 +403,7 @@ bool_t	set_trap( long x, long y, trap_t *trap )
 
 	dun->map.obj.mjr[y][x] = FACE_MJR_TRAP;
 	dun->map.obj.mnr[y][x] = FACE_MNR_NULL;
-	dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS;
+	dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_PASS | FLG_MAP_OBJ_LOOK;
 	dun->map.obj.flg[y][x] |= FLG_MAP_OBJ_LOOK_FLOOR;
 
 	set_trap_face_mnr( trap );
@@ -524,6 +528,8 @@ void	make_trap_room( long area_x, long area_y, long dun_lev )
 
 void	chk_trap_chest( item_t *chest, chr_t *chr, rate_t rate )
 {
+	bool_t	flg_free;
+
 	if( chr == NULL )
 		return;
 	if( chk_flg_or( chr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
@@ -533,12 +539,21 @@ void	chk_trap_chest( item_t *chest, chr_t *chr, rate_t rate )
 	if( chest->kind != ITEM_KIND_CHEST )
 		return;
 
-	if( !rate_randm( rate ) )
+	if( !rate_randm( rate ) ){
+		call_game_sound_play( SOUND_KIND_TRAP_SAFE, 1 );
 		return;
+	}
 
+	flg_free = TRUE;
+	if( chest->dat.chest.trap != NULL )
+		if( chest->dat.chest.trap->kind == TRAP_KIND_CHUTE )
+			flg_free = FALSE;
+
+	call_game_sound_play( SOUND_KIND_TRAP_CAUGHT, 1 );
 	caught_trap( chest->dat.chest.trap, chr );
 
-	free_trap_chest( chest );
+	if( flg_free )
+		free_trap_chest( chest );
 }
 
 /***************************************************************
@@ -586,6 +601,9 @@ void	chk_trap( chr_t *chr, chr_t *thief )
 
 	if( chr_roll( thief, ABL_KIND_THI, ABL_KIND_AGI,
 			trap->difficulty ) ){
+		if( is_mbr( chr ) || is_pet( chr ) )
+			call_game_sound_play( SOUND_KIND_TRAP_SAFE, 1 );
+
 		curs_attrset_chr( chr, +1, FALSE );
 		print_msg_mbr( chr, FLG_NULL, MSG_NOT_TRAPPED, chr->name );
 		curs_attrset_dflt();
@@ -634,6 +652,9 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 	if( chk_flg_or( chr->stat, FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 		return;
 
+	if( is_mbr( chr ) || is_pet( chr ) )
+		call_game_sound_play( SOUND_KIND_TRAP_CAUGHT, 1 );
+
 	if( is_mbr( chr ) ){
 		find_trap( trap );
 	} else {
@@ -649,7 +670,7 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 	}
 
 	g_dmy_chr.kind = CHR_KIND_NULL;
-	str_nz_cpy( g_dmy_chr.name, trap->tab->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( g_dmy_chr.name, trap->tab->name, CHR_NAME_MAX_BYTE );
 	g_dmy_chr.x = trap->x;
 	g_dmy_chr.y = trap->y;
 	g_dmy_chr.trgt.kind = get_trgt_kind_from_chr( chr );
@@ -822,6 +843,8 @@ void	disarm_trap( trap_t *p )
 	if( p == NULL )
 		return;
 
+	call_game_sound_play( SOUND_KIND_TRAP_DISARM, 1 );
+
 	dun = get_dun();
 
 	dun->map.obj.mjr[p->y][p->x] = FACE_MJR_FLOOR;
@@ -1465,3 +1488,16 @@ long	get_trap_tab_n( trap_kind_t kind )
 	return -1;
 }
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_trap_c( void )
+{
+	check_memory( check_memory_trap_c_trap_buf,
+			"trap.c: trap_buf" );
+	check_memory( check_memory_trap_c_trap_tab,
+			"trap.c: trap_tab" );
+	check_memory( check_memory_trap_c_g_dmy_chr,
+			"trap.c: g_dmy_chr" );
+}
