@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ver.h,v 1.63 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: ver.h,v 1.66 2011/01/09 01:58:25 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	VER_H
@@ -58,10 +58,10 @@
 #define	STR_HANDLE_2	"[RPG DOT], Whitecat, REFMAP"
 
 #define	STR_TITLE_3	" "
-#define	STR_HANDLE_3	"kokusi(yujyu), hiyo URARA"
+#define	STR_HANDLE_3	"kokusi(yujyu), hiyo, moja"
 
 #define	STR_TITLE_4	" "
-#define	STR_HANDLE_4	"and naramura"
+#define	STR_HANDLE_4	"URARA, naramura and Denzi"
 
 #define	STR_TITLE_5	"Photograph"
 #define	STR_HANDLE_5	"Yoshinori Kamimura"
@@ -69,6 +69,9 @@
 #define	STR_TITLE_6	"Music Production"
 #define	STR_HANDLE_6	"Presence of Music"
 
+#define	STR_TITLE_7	"Sound Effects"
+#define	STR_HANDLE_7	"OSA at The Match Makers"
+
 #define	STR_TITLE_THANKS	"Special Thanks"
 #define	STR_HANDLE_THANKS	"t-oikawa, TeaMiKL, nnn, lu and you"
 
@@ -91,6 +94,7 @@
 		"%20s  %-42s\n" \
 		"%20s  %-42s\n" \
 		"%20s  %-42s\n" \
+		"%20s  %-42s\n" \
 		"--------------------------------" \
 		"--------------------------------\n" \
 		""
@@ -106,6 +110,7 @@
 		STR_TITLE_4, STR_HANDLE_4, \
 		STR_TITLE_5, STR_HANDLE_5, \
 		STR_TITLE_6, STR_HANDLE_6, \
+		STR_TITLE_7, STR_HANDLE_7, \
 		STR_TITLE_THANKS, STR_HANDLE_THANKS
 
 #endif	/* VER_H */
